# coding: utf8
from __future__ import unicode_literals
PARTICIPLES = set("""
 έρποντας έχοντας αβανιάζοντας αβγατισμένος αγαπημένος αγαπώντας αγγίζοντας
 αγγιγμένος αγιασμένος αγιογραφώντας αγιοποιημένος αγιοποιώντας αγκαζαρισμένος
 αγκιστρωμένος αγκυλωμένος αγκυροβολημένος αγλακώντας αγνοημένος αγνοούμενος
 αγνωμονώντας αγοράζοντας αγορασμένος αγραυλώντας αγριεμένος αγριεύοντας
 αγριοκοιτώντας αγρυπνισμένος αγχωμένος αδειασμένος αδελφωμένος αδιαθετώντας
 αδικημένος αδικοπραγώντας αδρανοποιημένος αδυνατίζοντας αδυνατισμένος
 αηδιασμένος αηδονολαλώντας αθλοθετώντας αθλούμενος αθροίζοντας αθροισμένος
 αθωωμένος αιμάσσων αιματοβαμμένος αιματοβρεγμένος αιματοκυλισμένος
 αινώντας αισθηματολογώντας αισθητοποιώντας αισχρολογώντας αισχυνόμενος
 αιτούμενος αιτώντας αιφνιδιασμένος αιχμαλωτισμένος αιωρούμενος ακαθέλκυστος
 ακινητοποιημένος ακινητώντας ακολουθούμενος ακονίζοντας ακονισμένος
 ακουμπώντας ακουσμένος ακριβολογώντας ακριβοπληρωμένος ακριβοπουλημένος
 ακροβολισμένος ακροπατώντας ακρωτηριασμένος ακτινοβολώντας ακτινογραφώντας
 ακυρωθείς ακυρωμένος αλαλιασμένος αλατισμένος αλαφιασμένος αλαφρωμένος
 αλειμμένος αλεσμένος αλευρογυρισμένος αλευροποιώντας αλησμονώντας αλλάζοντας
 αλλαξοπιστώντας αλληγορώντας αλληθωρίζοντας αλληλεξαρτούμενος
 αλληλοεξαρτημένος αλληλομαχαιρωμένος αλληλοσυγκρουόμενος αλληλοτροφοδοτούμενος
 αλογονωμένος αλυσοδεμένος αλυχτώντας αλφαδιασμένος αλωνίζοντας αλωνισμένος
 αμβλυμμένος αμειβόμενος αμελημένος αμερικανοκρατούμενος αμεροληπτώντας
 αμολημένος αμολώντας αμπαλαρισμένος αμπαρωμένος αμποδεμένος αμυνόμενος
 αμφιλεγόμενος αμφισβητούμενος αμφισβητώντας αμφιταλαντευόμενος αναβαθμισμένος
 αναβαθμολογώντας αναβαλλόμενος αναβαπτισμένος αναβαστώντας αναβληθείς
 αναβοώντας αναβρασμένος αναβρυώντας αναγεγραμμένος αναγελώντας αναγεννώντας
 αναγνωρισμένος αναγορευμένος αναγουλιασμένος αναγραμμένος αναγραμματισμένος
 αναδασωμένος αναδειγμένος αναδημιουργημένος αναδημιουργώντας αναδημοσιευμένος
 αναδιπλασιασμένος αναδιπλωμένος αναδυόμενος αναζητημένος αναζητούμενος
 αναζωπυρωμένος αναθαρρώντας αναθεωρημένος αναθρεμμένος αναιρεθείς
 αναισθητοποιώντας ανακαθισμένος ανακαινίζοντας ανακαινιζόμενος ανακαινισμένος
 ανακατωμένος ανακινώντας ανακλαδισμένος ανακλιμένος ανακλινόμενος ανακλώντας
 ανακουφισμένος ανακυκλωμένος αναλογιζόμενος αναλογισθείς αναλογώντας
 αναλωθείς αναμαλλιασμένος αναμασημένος αναμειγμένος αναμειγνύοντας
 αναμεμειγμένος αναμεμιγμένος αναμενόμενος αναμερισμένος αναμεταδιδόμενος
 αναμετρώντας αναμιγμένος αναμιγνύοντας αναμμένος αναπαλαιωμένος αναπαραγόμενος
 αναπαυμένος αναπετώντας αναπηδώντας αναπλασμένος αναπληρωμένος
 αναπολούμενος αναπολώντας αναπροσαρμοσμένος αναπτερωμένος αναπτυγμένος
 αναπυρωμένος αναριγώντας αναρριχώμενος αναρροφημένος αναρροφώντας αναρρωμένος
 αναρτώντας αναρχούμενος αναρωτώντας ανασηκωμένος ανασκαλεμένος ανασκαμμένος
 ανασκευασμένος ανασκιρτώντας ανασκολοπισμένος ανασκοπώντας ανασκουμπωμένος
 αναστατωμένος αναστηλωμένος αναστημένος αναστομωμένος αναστυλωμένος
 ανασυγκροτώντας ανασυνιστώντας ανασυνταγμένος ανασυντεταγμένος ανασυρμένος
 ανατέλλων αναταραγμένος ανατεθειμένος ανατιμημένος ανατιμώντας ανατιναγμένος
 ανατοποθετημένος ανατοποθετώντας ανατρέπων ανατραπείς ανατριχιασμένος
 ανατροφοδοτώντας ανατσουτσουρωμένος ανατυπωμένος αναφερόμενος αναφλέγοντας
 αναφυτεμένος αναχαιτισμένος αναψηλαφώντας αναψοκοκκινισμένος ανδροκρατούμενος
 ανεβασμένος ανελκυσμένος ανεμισμένος ανεμοδαρμένος ανεξαρτητοποιημένος
 ανερευνώντας ανερχόμενος ανεσκαμμένος ανεστραμμένος ανευφημώντας
 ανεχόμενος ανηρημένος ανηφορώντας ανθιστάμενος ανθοβολώντας ανθοκομώντας
 ανθολογώντας ανθοστολισμένος ανθοφορεμένος ανθοφορώντας ανθυπομειδιώντας
 ανισοπεδοποιημένος ανιστορώντας ανιχνευμένος ανιώντας ανοιγμένος
 ανοικοδομημένος ανοικοδομώντας ανορθογραφώντας ανορθωμένος ανοσιουργώντας
 αντέχοντας ανταγαπώντας ανταδικώντας ανταλλαγμένος ανταλλασσόμενος ανταμωμένος
 ανταπαντώντας ανταποδομένος ανταποκρινόμενος ανταριασμένος αντασφαλισμένος
 αντεπαναστατώντας αντεστραμμένος αντευχαριστώντας αντηχώντας αντιβοώντας
 αντιγραμμένος αντιδανεισμένος αντιδικώντας αντιδονώντας αντικαθιστάμενος
 αντικατεστημένος αντικατοπτρισμένος αντικρισμένος αντιλέγων αντιλαμβανόμενος
 αντιμετωπιζόμενος αντιμετωπισμένος αντιμιλώντας αντιπαθώντας αντιπαραταγμένος
 αντιπολιτευόμενος αντιπροσκαλώντας αντιπροσωπευμένος αντιπροσωπευόμενος
 αντιστοιχισμένος αντιστοιχώντας αντιστραμμένος αντιστρατευόμενος
 αντιτιθέμενος αντιφρονώντας αντιφωνώντας αντιχαιρετώντας αντιχτυπώντας
 αντλούμενος αντραλισμένος αντρειεμένος αντροκαλώντας ανυμνώντας ανυπομονώντας
 ανυψωμένος ανυψωνόμενος ανωνυμογραφώντας αξιολογημένος αξιοποιώντας αξιωμένος
 απαγκιασμένος απαγκιστρωμένος απαγορευμένος απαγχονισμένος απαθανατισμένος
 απαιτούμενος απαιτώντας απαλειμμένος απαλλαγμένος απαλλοτριωμένος απαλυμένος
 απαντημένος απαξιωμένος απαριθμημένος απαρνημένος απαρνούμενος απαρτισμένος
 απασβεστωμένος απασχολημένος απασχολούμενος απατημένος απατώντας απαυδισμένος
 απαχθείς απεγκατεστημένος απεγκλωβισμένος απειθαρχώντας απειθώντας
 απεικονισμένος απειλημένος απειλούμενος απεκδεχόμενος απελευθερωμένος
 απενεργοποιημένος απενεργοποιώντας απεξαρτημένος απεραντολογώντας απερχόμενος
 απεσταλμένος απευαισθητοποιημένος απευαισθητοποιώντας απευθυνόμενος
 απηλλαγμένος απησχoλημένος απηυδισμένο απιστώντας απλοποιώντας απλουστευμένος
 απλώνοντας αποβεβλημένος αποβιβασμένος αποβιώντας αποβλέποντας αποβλακωμένος
 αποβλημένος αποβουτυρωμένος απογεγραμμένος απογειωμένος απογεμισμένος
 απογραμμένος απογυμνωμένος αποδίδων αποδεδειγμένος αποδεδομένος αποδεικνύοντας
 αποδελτιωμένος αποδεσμευμένος αποδεσμευόμενος αποδεχόμενος αποδιαλεγμένος
 αποδιδόμενος αποδιεθνοποιημένος αποδιεθνοποιώντας αποδιοργανωμένος
 αποδοκιμασμένος αποδομένος αποδοσμένος αποδυναμωμένος αποζημιωμένος αποζώντας
 αποθαμένος αποθαρρημένος αποθαρρυμένος αποθεραπευμένος αποθερισμένος
 αποθηκευμένος αποθηκεύοντας αποθηριωμένος αποθησαυρισμένος αποθρασυμένος
 αποικισμένος αποικοδομημένος αποικώντας αποκαθηλωμένος αποκαλυμμένος
 αποκαλώντας αποκαμωμένος αποκαρδιωμένος αποκαταστημένος αποκατεστημένος
 αποκεφαλισμένος αποκηρυγμένος αποκλεισμένος αποκληρωμένος αποκλιμακούμενος
 αποκλιμακώνοντας αποκοιμισμένος αποκολλημένος αποκολλώντας αποκομισμένος
 αποκομματικοποιημένος αποκορυφωμένος αποκοτώντας αποκρουσμένος αποκρυμμένος
 αποκρυσταλλωμένος αποκρύπτοντας αποκτημένος αποκτηνωμένος απολακτισμένος
 απολησμονημένος απολησμονώντας απολιθωμένος απολογηθείς απολογημένος
 απολυμένος απολυμασμένος απολυτρωμένος απολυόμενος απολωλώς απομένων
 απομαγνητοφωνημένος απομαγνητοφωνώντας απομακρυνόμενος απομακρυσμένος
 απομυθοποιημένος απομυθοποιώντας απομωραμένος αποναρκωμένος απονεκρωμένος
 απονενοημένος απονευρωμένος αποξενωμένος αποξεραμένος αποξεσμένος
 αποξεχνώντας αποξηλωμένος αποξηραμένος αποπαρμένος αποπερατωμένος αποπλέοντας
 αποπλανημένος αποπλανώντας αποπληρωμένος αποπλυμένος αποποιημένος
 αποπροσανατολισμένος αποπροσωποποιημένος αποπροσωποποιώντας
 απορημένος απορριμμένος απορροφημένος απορροφώντας απορρυθμισμένος
 αποσαθρωμένος αποσαρωμένος αποσαφηνιζόμενος αποσαφηνισμένος αποσβεσμένος
 αποσβολωμένος αποσιωπημένος αποσκεπασμένος αποσκιρτώντας αποσκληρυμένος
 αποσκοπώντας αποσκορακισμένος αποσοβημένος αποσοβώντας αποσταγμένος
 αποσταθεροποιώντας αποσταλαγμένος αποσταλμένος αποσταμένος αποστασιοποιημένος
 αποστεγνωμένος αποστειρωμένος αποστελλόμενος αποστερημένος αποστερώντας
 αποστηθισμένος αποστομωμένος αποστραβωμένος αποστραγγισμένος αποστρατευμένος
 αποστρατιωτικοποιημένος αποσυμπιεσμένος αποσυμφορημένος αποσυμφορώντας
 αποσυναρμολογούμενος αποσυνδεδεμένος αποσυνδεμένος αποσυνθεμένος
 αποσυντιθέμενος αποσυρμένος αποσυρόμενος αποσυσχετισμένος αποσφραγισμένος
 αποσχισθείς αποσχισμένος αποσωμένος αποταγμένος αποταμιευμένος αποτείνοντας
 αποτεινόμενος αποτελματωμένος αποτεφρωμένος αποτιμημένος αποτιμώντας
 αποτιτανωμένος αποτοιχισμένος αποτολμώντας αποτοξινωμένος αποτραβώντας
 αποτριχωμένος αποτροπιασμένος αποτρυγώντας αποτυπωμένος αποτυχημένος
 αποφασισμένος αποφεύγοντας αποφλοιωμένος αποφοιτώντας αποφορτισμένος
 αποφυλακιζόμενος αποφυλακισμένος αποχαιρετισμένος αποχαιρετώντας
 αποχαλώντας αποχαυνωμένος αποχλωριωμένος αποχρωματισμένος αποχρών αποχτημένος
 αποχωρισμένος αποχωρών αποψιλωμένος αποψυγμένος απρακτώντας απωθημένος
 αραδιασμένος αραθυμώντας αραιωμένος αραχνιασμένος αργοκινώντας αργοξυπνημένος
 αργών αρδευμένος αρθρογραφώντας αρθρωμένος αριθμημένος αρκούμενος αρκώντας
 αρματωμένος αρμεγμένος αρμενίζοντας αρμοσμένος αρμόζων αρνούμενος αροτριωμένος
 αρραβωνιασμένος αρρωστημένη αρρωστημένο αρρωστημένος αρρωστώντας αρτυμένος
 αρχίζοντας αρχαΐζων αρχειοθετημένος αρχινισμένος αρχινώντας αρωματισμένος
 ασεβώντας ασελγώντας ασημωμένος ασθενώντας ασθμαίνοντας ασκημένος ασκούμενος
 ασπασμένος ασπρισμένος ασταρωμένος αστειευόμενος αστειολογώντας αστερωμένος
 αστοχημένος αστοχώντας αστραποβολώντας αστροσπαρμένος αστροστεφανωμένος
 αστυνομοκρατούμενος ασφαλιζόμενος ασφαλισμένος ασφαλτοστρωμένος ασφαλτωμένος
 ασχημισμένος ασχολούμενος ατενίζοντας ατιμασμένος ατομικευμένος ατονώντας
 ατροφώντας ατσαλωμένος ατυχώντας αυγοκομμένος αυθαιρετώντας αυλακωμένος
 αυξάνοντας αυξανόμενος αυξημένος αυξομειωμένος αυτενεργώντας αυτοακυρωμένος
 αυτοανακηρυγμένος αυτοαπασχολούμενος αυτοαποκαλούμενος αυτοβιογραφούμενος
 αυτοδιαφημισμένος αυτοδιαχειριζόμενος αυτοδιορισμένος αυτοεξορισμένος
 αυτοκαθαριζόμενος αυτοκαταδικασμένος αυτοκαταργημένος αυτοκαταργούμενος
 αυτοματοποιημένος αυτονομαζόμενος αυτονομασμένος αυτονομημένος
 αυτοονομασμένος αυτοπαρουσιαζόμενος αυτοπαρουσιασμένος αυτοπεριορισμένος
 αυτορευστοποιούμενος αυτοσυγκρατημένος αυτοσυντηρημένος αυτοσυντηρούμενος
 αυτοτιμωρημένος αυτοτραυματισμένος αυτοτροφοδοτημένος αυτοτροφοδοτούμενος
 αυτοχειριαζόμενος αυτοχειριασμένος αυτοϊκανοποιημένος αυτοϋπονομευόμενος
 αφαιρεμένος αφαιρώντας αφανισμένος αφελληνισμένος αφερματίζοντας
 αφημένος αφηνιασμένος αφηρημένος αφηρωισμένος αφθονώντας αφιερωμένος
 αφιονισμένος αφισοκολλημένος αφισοκολλώντας αφλογιστώντας αφομοιωμένος
 αφοπλισμένος αφορεσμένος αφορισμένος αφορμισμένος αφορώντας αφοσιωμένος
 αφροστεφανωμένος αφυδατωμένος αφυπηρετώντας αφυπνισμένος αχαρτογράφητος
 αχνισμένος αχολογώντας αχρειολογώντας αχώντας αψιμαχώντας αύξουσα βάλλοντας
 βαθμολογημένος βαθμονομημένος βαθμονομώντας βαθουλωμένος βακχογαμημένη
 βαλκανοποιημένος βαλλόμενος βαλμένος βαλσαμωμένος βαλτωμένος βαμμένος
 βαραθρωμένος βαρβατεμένος βαρεμένος βαριεστημένος βαριεστώντας βαρυγκομισμένος
 βαρυγκωμώντας βαρυθυμώντας βαρυνόμενος βαρυπενθώντας βαρυστομαχιασμένος
 βασιζόμενος βασιλεμένος βασιλευόμενος βασισμένος βασκαμένος βασταγμένος
 βατεμένος βατσιναρισμένος βαττολογώντας βαυκαλισμένος βαυκαλώντας βαφτισμένος
 βεβαιωμένος βεβαρημένος βεβηλωμένος βεβιασμένος βεβλαμμένος βεβλημένος
 βελονιασμένος βελτιωμένος βερνικωμένος βιαιοπραγώντας βιασμένος
 βιδωμένος βικιποιημένος βιντεοσκοπημένος βιοδιασπώμενος βιομηχανοποιημένος
 βλαμμένος βλαστημώντας βλαστισμένος βλαστολογώντας βλασφημώντας βλεφαριασμένος
 βλογώντας βοήθεια:γρήγορη δημιουργία/μτχ- βοηθημένος βοηθούμενος βολεμένος
 βολοκοπώντας βομβαρδισμένος βοσκημένος βοσκώντας βοστρυχώντας βοτανισμένος
 βουβαμένος βουκολώντας βουλιαγμένος βουλιμιώντας βουλωμένος βουρβουλακώντας
 βουρλισμένος βουρτσισμένος βουρώντας βουτηγμένος βουτυρωμένος βοώντας
 βρακωμένος βρασμένος βραχνιασμένος βραχυκυκλωμένος βραχυλογώντας
 βρεφοκομώντας βρεχάμενος βρεχόμενος βρικολακιασμένος βρισμένος βρομισμένος
 βροντημένος βροντοφωνώντας βρυχώμενος βυζαγμένος βυθισμένος βυθομετρημένος
 βυθοσκοπώντας βυθώντας βωμολοχώντας γαγγραινιασμένος γαζωμένος
 γαλακτοποιώντας γαλβανισμένος γαληνεμένος γαλουχημένος γαμημένος γαμώμενος
 γανιασμένος γαντζωμένος γανωμένος γαργαλεμένος γαργαλημένος γαργαλισμένος
 γαρνιρισμένος γατσιασμένος γαυριώντας γγαστρωμένος γδαρμένος γδικημένος
 γειωμένος γελασμένος γελοιογραφημένος γελοιογραφώντας γελοιοποιημένος
 γεμισμένος γενικευμένος γενικολογώντας γεννηθείς γεννημένος γερασμένος
 γεροκομημένος γεροκομώντας γευματισμένος γεφυρωμένος γηπεδοποιημένος
 γηροκομημένος γηροκομώντας γητεμένος γιατρεμένος γιγαντεμένος γιγαντούμενος
 γινατεμένος γινόμενος γιομισμένος γιορτασμένος γιουχαρισμένος γιουχαϊσμένος
 γκαστρωμένος γκρεμισμένος γκρεμοτσακισμένος γλακώντας γλαρωμένος γλείφοντας
 γλεντοκοπώντας γλεντώντας γλιτωμένος γλυκαμένος γλυκοκοιμισμένος
 γλυκοκουβεντιασμένος γλυκομιλώντας γλυκοτραγουδημένος γλυκοφιλημένος
 γλυμμένος γλωσσοφαγωμένος γλύφοντας γνεσμένος γνοιασμένος γνωμοδοτώντας
 γνωστοποιημένος γοητευμένος γομωμένος γομώντας γονατισμένος γονιμοποιημένος
 γουρλωμένος γουρμασμένος γουρσουζεμένος γράφοντας γραδαρισμένος γραμμένος
 γραμμογραφώντας γραπωμένος γρασαρισμένος γρικώντας γριπιασμένος γριπωμένος
 γρονθοκοπώντας γρουσουζεμένος γυαλισμένος γυαλοκοπώντας γυμνασμένος γυμνωμένος
 γυρεμένος γυρισμένος γυψωμένος γωνιασμένος δέον δίνοντας δαγκαμένος δαγκωμένος
 δαιμονιώντας δαιμονολογώντας δαιμονοπαρμένος δακρυσμένος δακτυλογραφημένος
 δακτυλοδεικτώ δαμαλισμένος δαμασμένος δανειζόμενος δανειοδοτημένος
 δανεισμένος δαπανηθείς δαπανημένος δαρμένος δασκαλεμένος δασμολογημένος
 δασωμένος δαχτυλογραφημένος δαχτυλογραφώντας δείχνοντας δεδηλωμένος
 δεδομένος δεδουλευμένος δειγμένος δεινοπαθώντας δεκαπλασιασμένος
 δελεασμένος δεμένος δεματιασμένος δενδροφυτεμένος δεντροφυτεμένος δεντρωμένος
 δεσμευθείς δεσμευμένος δεσποζόμενος δευτερωμένος δεχόμενος δηλητηριασμένος
 δηλοποιώντας δηλωθείς δηλωμένος δημαγωγώντας δημευμένος δημηγορώντας
 δημιουργώντας δημοκοπώντας δημοπρατημένος δημοπρατώντας δημοσιευθείς
 δημοσιογραφώντας δημοσιοποιημένος δημοσιοποιώντας δημοσκοπημένος δημοσκοπώντας
 διαβάζοντας διαβαθμισμένος διαβασμένος διαβεβαιωμένος διαβεβλημένος
 διαβολοσταλμένος διαβρωμένος διαγγελμένος διαγκωνισμένος διαγουμισμένος
 διαγραμμισμένος διαγωνιζόμενος διαδεδομένος διαδεχθείς διαδηλωμένος
 διαζευγμένος διαθέτοντας διαθερμασμένος διαθλασμένος διαθλώντας διαθρυλώντας
 διαιτώμενος διαιωνισμένος διακανονισμένος διακείμενος διακεκριμένος
 διακηρυγμένος διακηρύσσοντας διακινδυνευμένος διακινημένος διακινώντας
 διακονώντας διακορευμένη διακορευμένος διακοσμημένος διακριβωμένος
 διακυβερνώντας διακυβευμένος διακωμωδημένος διακωμωδώντας διαλαλημένος
 διαλαμβανόμενος διαλείπων διαλεγμένος διαλευκασμένος διαλογισμένος διαλυμένος
 διαμαρτυρόμενος διαμαρτυρώντας διαμελίζοντας διαμελισμένος διαμερισμένος
 διαμετρημένος διαμετρώντας διαμηνυμένος διαμοιρασμένος διαμορφωμένος
 διαμφισβητώντας διανεμημένος διανεμισμένος διανθισμένος διανθώντας
 διανοούμενη διανυσμένος διαολεμένος διαπαιδαγωγημένος διαπερασμένος
 διαπιστωμένος διαπιστώνοντας διαπλέοντας διαπλασμένος διαπλατυμένος
 διαπλεγμένος διαπλεκόμενη διαπλεκόμενο διαπλεκόμενος διαπληκτισμένος
 διαπομπευόμενος διαπορθμεμένος διαπορώντας διαποτισμένος διαπραγμένος
 διαρκώντας διαρπαγμένος διαρρυθμισμένος διασαφηνισμένος διασαφώντας
 διασκελισμένος διασκευασμένος διασκορπισμένος διασπαθισμένος διασπασμένος
 διαστρεβλωμένος διαστρεβλώνοντας διασυνδεδεμένος διασυρμένος διασφαλισμένος
 διασωσμένος διαταγμένος διαταραγμένος διατεθειμένος διατεταγμένος διατηρημένος
 διατιμημένος διατιμώντας διατρανωμένος διατρεφόμενος διατρυπημένος
 διατυπωμένος διαυγασμένος διαφαινόμενος διαφεντευμένος διαφημιζόμενος
 διαφθαρμένος διαφιλονικώντας διαφοροποιημένος διαφυλαγμένος διαφωνώντας
 διαχαραγμένος διαχειμασμένος διαχειρισμένος διαχυμένος διαχωρισμένος
 διαψευσμένος διαψυγμένος διβολισμένος διδάσκων διδαγμένος διεγείροντας
 διεγνωσμένος διεθνοποιημένος διεκδικημένος διεκπεραιωμένος διεκτραγωδώντας
 διενεργημένος διενεργώντας διεξαγμένος διεξαχθείς διερευνημένος διερμηνευμένος
 διερρηγμένος διεσπαρμένος διεσταλμένος διευθετώντας διευκολύνοντας
 διευκρινισμένος διευκρινώντας διευρυμένος διευρυνόμενος διευρύνοντας
 διηγημένος διηγούμενος διηγώντας διηθημένος διιστάμενος δικαιοδοτώντας
 δικαιούμενος δικαιωμένος δικασμένος δικηγορώντας δικτυωμένος διογκωμένος
 διομολογημένος διομολογώντας διοργανωμένος διορθωμένος διορισμένος διορώντας
 διπλαρωμένος διπλασιασμένος διπλοεγγεγραμμένος διπλοκλειδωμένος
 διπλωμένος διυλισμένος διφορούμενος διφωσφορυλιωμένος διχλωριωμένος
 διχογνωμώντας διχοτομημένος διχοτομώντας διψασμένος διωγμένος διωχθείς
 δοθείς δοθείς δοκιμασμένος δολοπλοκώντας δολοφονημένος δολωμένος δομημένος
 δοξασμένος δοξολογημένος δοξολογώντας δοσμένος δουλεμένος δραματοποιημένος
 δραστηριοποιημένος δραστηριοποιώντας δραχμοποιημένος δραχμοποιώντας
 δρομολογώντας δροσισμένος δροσολογημένος δροσολογώντας δρων δυνάμενος
 δυναστευμένος δυσανασχετώντας δυσαρεστημένος δυσθυμώντας δυσκολεμένος
 δυσπιστώντας δυστοκώντας δυστροπώντας δυστυχισμένος δυστυχώντας δυσφημισμένος
 δωρισμένος δωροδοκημένος δωροδοκώντας δωροληπτώντας δύων εγγεγραμμένος
 εγγυοδοτώντας εγκαθιδρυμένος εγκαινιασμένος εγκαλούμενος εγκαλών εγκαλώντας
 εγκαρτερώντας εγκαταλειμμένος εγκαταλελειμμένος εγκαταστημένος εγκατεστημένος
 εγκιβωτισμένος εγκλεισμένος εγκλιματισμένος εγκλωβισμένος εγκολλώντας
 εγκριμένος εγκυμονώντας εγκυστώντας εγκυτιώμενος εγκωμιασμένος εγνωσμένος
 εγχειρημένος εγχειρώντας εδραιωμένος εθισμένος ειδοποιημένος εικαζόμενος
 εικονογραφημένος εικοτολογώντας ειλημμένος ειπωμένος ειρημένος ειρηνεμένος
 ειρωνευόμενος εισαγόμενος εισαχθείς εισηγμένη εισηγμένο εισηγμένος εισορμώντας
 εισχωρώντας εκβαθυμένος εκβιομηχανισμένος εκγυμνασμένος εκδηλωμένος
 εκδικασμένος εκδιωγμένος εκδοθείς εκδομένος εκθέτοντας εκθαμβωμένος
 εκθηλυσμένος εκθολούμενος εκθρονισμένος εκκαθαρισμένος εκκαλών εκκαλώντας
 εκκινώντας εκκλησιασμένος εκκοκκισμένος εκκολαπτόμενος εκκρεμώντας εκκριμένος
 εκλεγμένος εκλεπτυσμένος εκλιπαρώντας εκλιπούσα εκλογικευμένος εκμαυλισμένος
 εκμεταλλευόμενος εκμηδενισμένος εκμισθωμένος εκμυστηρευμένος εκνευρισμένος
 εκπαιδευόμενος εκπατρισμένος εκπεφρασμένος εκπλέοντας εκπληρωμένος εκποιημένος
 εκπολιτισμένος εκπονημένος εκπορθώντας εκπροσωπημένος εκπροσωπώντας
 εκριζωμένος εκσλαβισμένος εκσπώντας εκστασιασμένος εκστομισμένος
 εκσυγχρονισμένος εκταμιευμένος εκτεθειμένος εκτεινόμενος εκτελεσμένος
 εκτελωνισμένος εκτεταμένος εκτιμημένος εκτιμώμενος εκτιμώντας εκτιναγμένος
 εκτοξευμένος εκτοπισμένος εκτουρκισμένος εκτραχηλισμένος εκτροχιασμένος
 εκτυφλωμένος εκφαυλισμένος εκφερόμενος εκφοβίζοντας εκφοβισμένος εκφοβώντας
 εκφρασμένος εκφυλισμένος εκφωνημένος εκχειλισμένος εκχερσωμένος εκχυλισθείς
 ελαιοχρωματισμένος ελαττωμένος ελαττώνοντας ελαφρωμένος ελαχιστοποιημένος
 ελεγχόμενος ελεεινολογώντας ελευθεροκοινωνώντας ελευθερωμένος ελλείπων
 ελπίζοντας εμβαπτιζόμενος εμβολιασμένος εμβολισμένος εμμένοντας εμπαιγμένος
 εμπιστευόμενος εμπλεκόμενος εμπλουτισμένος εμπνευσμένος εμποδισμένος
 εμποτισμένος εμφανισμένος εμφιαλωμένος εμφιλοχωρώντας εμφυτευμένος εμψυχωμένος
 ενάγουσα ενάγων εναγκαλισμένος εναγομένη εναγόμενος ενανθρακωμένος
 εναντιωμένος εναποθηκευμένος ενασκημένος ενασκούμενος ενασκώντας ενασχολημένος
 ενδημώντας ενδοσυνδεόμενoς ενδυναμωμένος ενεργημένος ενεργοποιημένος
 ενεργούμενος ενεργώντας ενηλικιωμένος ενημερωμένος ενθαρρυμένος ενθαρρύνοντας
 ενθρονισμένος ενθυλακωμένος ενθυμούμενος ενθυμώντας ενισχυμένος ενισχύοντας
 ενοικιασμένος ενοικώντας ενοποιημένος ενοποιώντας ενορχηστρωμένος ενορώντας
 ενοχλημένος ενοχλώντας ενοχοποιημένος ενσαρκωμένος ενσφηνωμένος ενσωματωμένος
 εντατικοποιημένος ενταφιασμένος εντείνοντας εντεινόμενος εντεταλμένος
 εντοιχισμένος εντοπισμένος εντροπισμένος εντυπωμένος εντυπωσιασμένος
 ενωμένος ενόν ενώνοντας εξέχων εξαγγελθείς εξαγγελμένος εξαγιασμένος
 εξαγορασμένος εξαγριωμένος εξαγόμενος εξαερισμένος εξαερωμένος εξαθλιωμένος
 εξακοντισμένος εξακριβωμένος εξαλειμμένος εξαναγκασμένος εξανδραποδισμένος
 εξανθρωπισμένος εξαντλημένος εξαπατημένος εξαπατώντας εξαπλασιασμένος
 εξαργυρωμένος εξαρθρωμένος εξαρτώμενος εξαρχαϊσμένος εξασθενίζοντας
 εξασθενισμένος εξασθενώντας εξασκημένος εξασφαλισμένος εξατμισμένος
 εξαφανισμένος εξαφρισμένος εξαχθείς εξαχρειωμένος εξαϋλωμένος εξεγερμένος
 εξελιγμένος εξελληνισμένος εξεμώντας εξεργασμένος εξερεθισμένος εξερευνημένος
 εξευγενισμένος εξευμενισμένος εξευρωπαϊσμένος εξευτελισμένος εξηγημένος
 εξημερωμένος εξημμένος εξιδανικευμένος εξιλεωμένος εξισλαμισμένος
 εξισορροπώντας εξιστορημένος εξιστορώντας εξισωμένος εξισώνοντας εξιταρισμένος
 εξοβελισμένος εξογκωμένος εξοδευμένος εξοικειωμένος εξοικονομώντας
 εξομαλυμένος εξομαλυσμένος εξομοιωμένος εξομολογημένος εξονειδισμένος
 εξονυχισμένος εξοπλισμένος εξοργισμένος εξορισμένος εξορκισμένος εξορμώντας
 εξοστρακισμένος εξουδετερωμένος εξουθενωμένος εξουσιασμένος εξουσιοδοτημένος
 εξοφερόμενος εξοφλημένος εξυβρισμένος εξυγιασμένος εξυμνώντας εξυπηρετημένος
 εξυπνώντας εξυφασμένος εξυψωμένος εξωθημένος εξωθούμενος εξωνημένος
 εξωραϊσμένος εξωτερικευμένος εορτάζων εορτασμένος επαγρυπνώντας επαινεμένος
 επαληθευμένος επαναλαμβανόμενος επαναπατριζόμενος επαναπατρισμένος
 επαναπλέοντας επαναπροωθώντας επαναστατημένος επαναστατώντας επανασυνδεμένος
 επανατοποθετώντας επαναφορτιζόμενος επανδρωμένος επανειλημμένος επανεκδομένος
 επανεμφανιζόμενος επανενταγμένος επανεξετασμένος επανιδρυμένος επανορθωμένος
 επαπειλώντας επαργυρωμένος επαρκώντας επαυξημένος επεκτεινόμενος επενδυμένος
 επεξεργασμένος επεξηγημένος επερχόμενος επερωτώντας επευφημούμενος
 επηρεασμένος επηρμένος επηυξημένος επιβαρυμένος επιβαρυνόμενος επιβεβαιωμένος
 επιβιβασμένος επιβοηθώντας επιβραβευμένος επιβραδύνοντας επιδειγμένος
 επιδεινωμένος επιδεινώνοντας επιδικασμένος επιδιορθωμένος επιδιωγμένος
 επιδιώκοντας επιδοκιμασμένος επιδοτημένος επιδοτούμενος επιδοτώντας επιδρών
 επιζών επιζώντας επιθεωρημένος επιθεωρώντας επιθυμώντας επικαιροποιημένος
 επικαρπωμένος επικασσιτερωμένος επικείμενος επικεντρωμένος επικηρυγμένος
 επικολλημένος επικολλώντας επικουρώντας επικρατώντας επικριμένος επικροτημένος
 επιλαχών επιλεγμένος επιλυμένος επιμένοντας επιμένων επιμαρτυρώντας
 επιμελούμενος επιμερισμένος επιμεταλλωμένος επιμετρημένος επιμετρώντας
 επιμορφωμένος επινοημένος επινοώντας επιπεδωμένος επιπεδώντας επιπλέοντας
 επιπληγμένος επιπλωμένος επιπωματισμένος επισημασμένος επισημοποιημένος
 επισκευασμένος επισκιασμένος επισκοπώντας επισκοτισμένος επισμαλτωμένος
 επιστατώντας επιστεγασμένος επιστεμμένος επιστρατευμένος επιστρατεύοντας
 επιστρωμένος επισυνημμένος επισφραγισμένος επισωρευμένος επιταγμένος
 επιταχύνοντας επιτείνοντας επιτετραμμένος επιτηδευμένος επιτηρώντας
 επιτιμώντας επιτρέποντας επιφοιτώντας επιφορτισμένος επιφυλαγμένος
 επιχειρημένος επιχορηγημένος επιχορηγώντας επιχρισμένος επιχρυσωμένος
 επιχωματωμένος επιών εποικισμένος εποικοδομώντας εποικώντας επονομαζόμενος
 επουλωμένος εποφθαλμιώντας εποχούμενος επωασμένος επωμισμένος επωφελημένος
 εργώντας ερειπωμένος ερευνημένος ερημοδικώντας ερημωμένος ερματίζοντας
 ερμηνευμένος ερχόμενος ερωτευμένος ερωτημένος ερωτώμενος ερωτώντας εσκαμμένος
 εσταυρωμένος εστιασμένος εσφαλμένος εσωκλεισμένος ετεροχρονισμένος
 ευαγγελισμένος ευαισθητοποιημένος ευαισθητοποιώντας ευαρεστημένος ευαρεστώντας
 ευδαιμονώντας ευδοκιμών ευδοκιμώντας ευδοκώντας ευελπιστώντας ευεργετημένος
 ευθυγραμμισμένος ευθυμογραφώντας ευθυμολογώντας ευθυμώντας ευλογημένος
 ευνοούμενος ευνουχισμένος ευπορώντας ευπρεπισμένος ευρυμένος ευρωτιώντας
 ευσταθώντας ευστοχώντας ευτελισμένος ευτρεπισμένος ευτυχισμένος ευτυχώντας
 ευχαριστημένος ευωδιασμένος ευωδώντας εφαπτόμενος εφαρμοσμένος εφημερεύων
 εφησυχασμένος εφιστώντας εφοπλισμένος εφυαλωμένος ζαβλακωμένος ζαβωμένος
 ζαλισμένος ζαλωμένος ζαρωμένος ζαχαριασμένος ζαχαρωμένος ζεμένος ζεματισμένος
 ζεστοκοπημένος ζευγαρισμένος ζευγαρωμένος ζηλεμένος ζηλοφθονώντας ζητημένος
 ζητώντας ζορισμένος ζουλιγμένος ζουμαρισμένος ζουπιγμένος ζουριασμένος
 ζοχαδιασμένος ζυγιασμένος ζυγισμένος ζυγοσταθμισμένος ζυγωμένος ζυμωμένος
 ζωγραφισμένος ζωγραφώντας ζωηρεμένος ζωντανεμένος ζωογονημένος ζωοποιημένος
 ηγιασμένος ηγούμενος ηδονισμένος ηθελημένος ηθικολογώντας ηθικοποιημένος
 ηθολογώντας ηλεκτρισμένος ηλεκτροδοτώντας ηλεκτρονικοποιημένος
 ηλιασμένος ηλικιωμένος ημερεμένος ημερωμένος ημιταυτοχρονισμένος ηνιοχώντας
 ηττημένος ηυξημένος ηχοβολισμένος ηχογραφημένος ηχολογώντας θέλοντας
 θαλασσοκρατώντας θαλασσομαχώντας θαλασσοπνιγμένος θαλασσοποιημένος
 θαλασσωμένος θαμβωμένος θαμμένος θαμπωμένος θανατωμένος θαρρεμένος θαρρώντας
 θαυματουργώντας θειαφισμένος θελημένος θελιασμένος θεμελιωμένος θεοβλαβούμενος
 θεολογώντας θεοποιημένος θεοποιώντας θεοσεβούμενος θεοσοφώντας θεοφοβούμενος
 θεριακωμένος θεριεμένος θερισμένος θερμομετρημένος θερμομετρώντας
 θεσμοθετημένος θεσπισμένος θεωρηθείς θεωρημένος θεωρητικολογώντας θεωρούμενος
 θηκαρισμένος θηλασμένος θηλιασμένος θηλυκωμένος θημωνιασμένος θησαυρισμένος
 θλιμμένος θλων θολωμένος θορυβημένος θορυβώντας θρασεμένος θρασομανώντας
 θρηνημένος θρηνολογώντας θρηνωδώντας θριαμβολογώντας θρονιασμένος θροώντας
 θρυμματισμένος θρυψαλιασμένος θυμιασμένος θυμιατισμένος θυμωμένος
 θυσιαζόμενος θυσιασμένος θωπευμένος θωρακισμένος ιατρεμένος ιδανικευμένος
 ιδιοκατοικημένος ιδιοκατοικώντας ιδιοπαραγώμενος ιδιοποιημένος
 ιδροκοπημένος ιδρυμένος ιδρωμένος ιδωμένος ιεραρχημένος ιερολογώντας
 ικανοποιημένος ιμβερτοποιήμενος ιονισμένος ιππευμένος ιπτάμενος ιριδισμένος
 ισιασμένος ισιωμένος ισοζυγιασμένος ισοζυγισμένος ισοζυγώντας ισοπεδωμένος
 ισοσκελισμένος ισοσταθμισμένος ισοσταθμώντας ισοσυγκερασμένος ισοφαρισμένος
 ιστιοπλοώντας ιστολογώντας ιστορημένος ιστορώντας ισχνεμένος ισχυρισμένος
 ιχνευμένος ιχνογραφημένος ιχνογραφώντας κάνοντας καβαλημένος καβατζωμένος
 καδραρισμένος καδρονιασμένος καζανιασμένος καζαντισμένος καημένος
 καθαγνισμένος καθαρισμένος καθαρογραμμένος καθαρογραφώντας καθελκυσμένος
 καθετηριασμένος καθετοποιημένος καθηλωμένος καθημαγμένος καθησυχασμένος
 καθιερωθείς καθιερωμένος καθισμένος καθιστάμενος καθοδηγημένος καθομολογώντας
 καθορώντας καθοσιωμένος καθούμενος καθρεπτισμένος καθρεφτισμένος καθυβρισμένος
 καθυποταγμένος καθυποχρεώντας καθυστερώντας καιροφυλαχτώντας κακαδιασμένος
 κακισμένος κακιωμένος κακοβαλμένος κακογαμημένος κακογεννημένος κακογεννώντας
 κακοδαιμονώντας κακοδιοικημένος κακοδιοικώντας κακοδοξώντας κακοδουλεμένος
 κακοζώντας κακοθανατισμένος κακοκαρδισμένος κακολογημένος κακολογιασμένος
 κακομεταχειρισμένος κακομιλώντας κακομοιριασμένος κακονυχτισμένος
 κακοπαθημένος κακοπαθώντας κακοπαντρεμένος κακοπερασμένος κακοπερνώντας
 κακοπληρωμένος κακοποιημένος κακοραμμένος κακοστομαχιασμένος κακοσυνεμένος
 κακοσυστημένος κακοτυπωμένος κακοτυχισμένος κακουργημένος κακουργώντας
 κακοφτιαγμένος κακοχρονισμένος κακοχωνεμένος κακοψημένος καλαθιασμένος
 καλαρισμένος καλαφατισμένος καλαϊσμένος καλεσμένος καλημερισμένος
 καληνωρισμένος καλιγωμένος καλλιγραφώντας καλλιεργημένος καλλιλογώντας
 καλλιτεχνώντας καλλουργώντας καλλωπισμένος καλμαρισμένος καλοβαστώντας
 καλογεννώντας καλογυαλισμένος καλοδεχάμενος καλοδεχούμενος καλοδουλεμένος
 καλοεξετασμένος καλοζυγιασμένος καλοζυγισμένος καλοζωισμένος καλοζώντας
 καλοκαρδισμένος καλολογιασμένος καλομαθημένος καλομελετημένος καλομελετώντας
 καλομιλώντας καλοναρχώντας καλοπαντρεμένος καλοπερνώντας καλοπεσμένος
 καλοπληροφορημένος καλοπληρωμένος καλοσκαμνισμένος καλοστρωμένος
 καλοτρώγοντας καλοτυχισμένος καλουμαρισμένος καλουπωμένος καλοφαγωμένος
 καλοχωνεμένος καλοψημένος καλοψυχισμένος καλπάζων καλυμμένος καλωδιωμένος
 καλύπτοντας καμένος καμακισμένος καμακωμένος καμαρωμένος καμινιασμένος
 καμουφλαρισμένος καμπουριασμένος καμπυλωμένος καμωμένος κανακισμένος
 κανονιοβολημένος κανονιοβολώντας καπακωμένος καπαρωμένος καπελωμένος
 καπιστρωμένος καπλαντισμένος καπνισμένος καραβοτσακισμένος καραμελιασμένος
 καρατομημένος καρατομώντας καρατσεκαρισμένος καρβουνιασμένος καργαρισμένος
 καρδιοχτυπώντας καρικωμένος καρκινοβατώντας καρουλιασμένος καρπαζωμένος
 καρπολογώντας καρποφορώντας καρπούμενος καρπωμένος καρτερεμένος καρυδωμένος
 καρφιτσωμένος καρφωμένος κασελιασμένος κασιδιασμένος κασσιτερωμένος κατέχοντας
 καταβαλλόμενος καταβαραθρωμένος καταβεβλημένος καταβλημένος καταβοδωμένος
 καταβολιασμένος καταβρεγμένος καταβρομισμένος καταβροχθίζοντας
 καταβυθισμένος καταγγέλλων καταγγελθείς καταγγελμένος καταγεγραμμένος
 καταγινωμένος καταγοητευμένος καταγραμμένος καταγόμενος καταδαμασμένος
 καταδαπανώντας καταδημαγωγώντας καταδικασθείς καταδικασμένος καταδιωγμένος
 καταζητούμενος καταζητώντας καταθλιμμένος καταθορυβημένος καταθορυβώντας
 κατακαμένος κατακεραυνωμένος κατακερματισμένος κατακιτρινισμένος
 κατακλεμμένος κατακλυσμένος κατακοκκινισμένος κατακομμένος κατακουρασμένος
 κατακρατημένος κατακρατώντας κατακρεουργημένος κατακρεουργώντας
 κατακριμένος κατακτημένος κατακυριευμένος κατακυρωθείς κατακυρωμένος
 καταλαγιασμένος καταλαλώντας καταλασπωμένος καταλερωμένος καταλογισμένος
 καταλυμένος καταλυπημένος καταλυπώντας καταλώντας καταμαρτυρώντας
 καταμαυρισμένος καταμερισμένος καταμετρηθείς καταμετρημένος καταμετρώντας
 καταναγκασμένος καταναλωθείς καταναλωμένος καταναυμαχώντας κατανεμηθείς
 κατανικημένος κατανικώντας κατανοημένος καταντημένος καταντροπιασμένος
 καταξεσκισμένος καταξεσχισμένος καταξιωμένος καταξοδεμένος καταξοδιασμένος
 καταπατώντας καταπαυμένος καταπεσμένος καταπιασμένος καταπιεζόμενος
 καταπικραμένος καταπλέοντας καταπλέων καταπλακωμένος καταπληγωμένος
 καταπλημμυρώντας καταπνιγμένος καταπολεμημένος καταπονημένος καταποντισμένος
 καταπραϋμένος καταπτοημένος καταργημένος καταργούμενος καταριθμημένος
 καταρρέων καταρρακωμένος καταρριμμένος καταρτισμένος κατασβησμένος
 κατασκαμμένος κατασκευασμένος κατασκηνωμένος κατασκιασμένος κατασκονισμένος
 κατασκοτωμένος κατασκουριασμένος κατασπαραγμένος κατασπαταλημένος
 κατασπιλωμένος κατασταλαγμένος κατασταλμένος καταστενοχωρημένος
 καταστρατηγημένος καταστρατηγώντας καταστρεμμένος καταστρωμένος
 κατασυκοφαντώντας κατασυντριμμένος κατασφαγμένος κατασχεθείς κατασχεμένος
 καταταλαιπωρημένος καταταλαιπωρώντας καταταραγμένος κατατεθειμένος
 κατατετμημένος κατατοπισμένος κατατραυματισμένος κατατρεγμένος κατατριμμένος
 κατατροπωμένος κατατρυπημένος κατατρυπώντας κατατσακισμένος κατατυραννισμένος
 καταυγασμένος καταυλισμένος καταφαγωμένος καταφρονημένος καταφρονώντας
 καταχειροκροτώντας καταχεσμένος καταχνιασμένος καταχραζόμενος καταχρασμένος
 καταχτημένος καταχτώντας καταχωμένος καταχωρημένος καταχωρισμένος καταχωρώντας
 καταψηφισμένος καταψυγμένος καταϊδρωμένος καταϋποχρεωμένος κατεβασμένος
 κατειλημμένος κατενθουσιασμένος κατεπείγων κατεργασμένος κατερειπωμένος
 κατεστημένος κατεστραμμένος κατευθυνόμενος κατευνασμένος κατευοδωμένος
 κατηγορημένος κατηχουμένη κατηχούμενη κατηχούμενος κατιούσα κατιών
 κατονομασμένος κατοπτρισμένος κατορθωμένος κατουρημένος κατοχυρωμένος
 κατραμωμένος κατσαδιασμένος κατσαρωμένος κατσιασμένος κατσιποδιασμένος
 καυλωμένος καυτηριασμένος καυχησιολογώντας καψαλισμένος καψωμένος κβαντισμένος
 κεκαμμένος κεκανονισμένος κεκαρμένος κεκαρμένος κεκλεισμένος κεκορεσμένος
 κελαδώντας κεντημένος κεντρισμένος κεραμιδωμένος κερασμένος κερατωμένος
 κεραυνοβολώντας κεραυνωμένος κερδισμένος κερδοσκοπώντας κερματισμένος
 κερωμένος κεφαλαιοποιημένος κεφαλαιοποιώντας κεχαριτωμένος κεχρισμένος
 κηδεμονευμένος κηλιδωμένος κηπεμένος κηρυγμένος κιαλαρισμένος κιβδηλεμένος
 κιθαρωδώντας κιμαδιασμένος κινδυνολογώντας κινηματογραφημένος
 κινητοποιημένος κινητοποιώντας κινούμενος κιτρινισμένος κλαδεμένος κλαδωμένος
 κλαπέν κλαπείς κλαπείσα κλασαυχενισμένος κλασμένος κλαταρισμένος κλείνοντας
 κλειδομανταλωμένος κλειδωμένος κλεισμένος κλειώντας κλεμμένος κληροδοτημένος
 κληρωμένος κλητευμένος κλιμένος κλιμακούμενος κλονιζόμενος κλονισμένος
 κλοτσώντας κλουβιασμένος κλυδωνισμένος κλωθογυρισμένος κλωσημένος κλωσμένος
 κλωτσημένος κλωτσώντας κνισμένος κοιλοπονώντας κοιμισμένος κοινολογημένος
 κοινοποιημένος κοινοποιώντας κοινωνικοποιημένος κοινωνικοποιώντας κοιταγμένος
 κοκαλιασμένος κοκαλωμένος κοκκινισμένος κολακευμένος κολεχτιβοποιώντας
 κολλημένος κολοβωμένος κολυμπημένος κολυμπώντας κολώντας κομισμένος κομμένος
 κομματισμένος κομουνισμένος κομπλεξαρισμένος κομποδεμένος κομπορρημονώντας
 κονιοποιώντας κονιορτοποιημένος κονομημένος κονσερβοποιημένος
 κοντροκρατώντας κοντρολαρισμένος κοντυμένος κοπανημένος κοπανισμένος
 κοπιαρισμένος κοπιώντας κοπρισμένος κοπροσκυλώντας κορακιασμένος κορδακισμένος
 κορδωμένος κορεσμένος κοριασμένος κορνιζαρισμένος κορνιζωμένος κοροϊδεμένος
 κορυβαντιώντας κορυφωμένος κορφολογημένος κορφολογώντας κορωμένος
 κοσμημένος κοστολογημένος κοστολογώντας κοτσαρισμένος κοτώντας κουβαλημένος
 κουβεντιασμένος κουδουνισμένος κουκουλωμένος κουλαμένος κουλαντρισμένος
 κουμανταρισμένος κουμπαριασμένος κουμπωμένος κουνημένος κουντώντας κουνώντας
 κουρασμένος κουρδισμένος κουρελιασμένος κουρεμένος κουρκουτιασμένος
 κουρντισμένος κουρσεμένος κουρταλώντας κουτουλημένος κουτουλισμένος
 κουτουπώνοντας κουτρουβαλιασμένος κουτρουβαλώντας κουτρώντας κουτσαίνοντας
 κουτσομπολεμένος κουτσουλημένος κουτσουλισμένος κουτσουλώντας κουτσουρεμένος
 κουφωμένος κοφινιασμένος κοχλιωμένος κοψομεσιασμένος κοψοχολιασμένος κραγμένος
 κρασπεδωμένος κρασωμένος κραταιωμένος κρατημένος κρατικοποιημένος
 κρατούμενος κρατώντας κρεβατωμένος κρεμάμενος κρεμανταλιασμένος κρεμασμένος
 κρεουργημένος κρεουργώντας κρεπαρισμένος κρημνισμένος κρηπιδωμένος
 κριμένος κριματισμένος κριτικαρισμένος κροταλισμένος κροτώντας κρουσμένος
 κρυολογημένος κρυπτογραφημένος κρυπτογραφώντας κρυσταλλιασμένος κρυσταλλωμένος
 κρυφοκοιτώντας κρυωμένος κτενισμένος κτερισμένος κτηνοβατώντας κτισμένος
 κτυπώντας κυβερνημένος κυβερνών κυβισμένος κυκλοφορημένος κυκλωμένος
 κυλινδώντας κυλισμένος κυμαινόμενος κυμβαλισμένος κυνηγημένος κυοφορημένος
 κυριαρχώντας κυριευμένος κυριολεκτώντας κυριολεχτώντας κυρτωμένος κυρωμένος
 κωδικοποιώντας κωδωνισμένος κωλυόμενος κωλωμένος κωπηλατώντας λέγοντας λήγων
 λαβωμένος λαγαρισμένος λαγγεμένος λαγιασμένος λαγοθηρώντας λαγοκοιμισμένος
 λαθεμένος λαθρακιασμένος λακισμένος λακτισμένος λακώντας λαλημένος
 λαμπαδιασμένος λαμπικαρισμένος λαμποκοπώντας λαναρισμένος λανθάνων λανθασμένος
 λαξεμένος λαξευμένος λαξεύοντας λαπαδιασμένος λασκαρισμένος λασπωμένος
 λατομώντας λατρεμένος λαφιασμένος λαφυραγωγημένος λαχανιάζοντας λαχανιασμένος
 λαχταρώντας λεγάμενος λεηλατημένος λειασμένος λειτουργημένος λειτουργώντας
 λεκιασμένος λελογισμένος λεξικογραφημένος λεπτολογημένος λεπτολογώντας
 λερωμένος λευκασμένος λευκοφορώντας λευτερωμένος λευχειμονώντας ληγμένος
 λημματολογώντας λησμονημένος ληστεμένος ληστοκρατημένος λιανεμένος λιανισμένος
 λιασμένος λιβανισμένος λιβελογραφώντας λιγδιασμένος λιγδωμένος λιγνεμένος
 λιγοστεύοντας λιθοβολημένος λιθογραφημένος λιθοδομημένος λιθοδομώντας
 λικνισμένος λιμαρισμένος λιμασμένος λιμνάζων λιμνασμένος λιμοκτονώντας
 λιπασμένος λιποθυμισμένος λιποταχτώντας λιποψυχώντας λιτανεμένος λιχνεμένος
 λιχουδεμένος λιωμένος λογαριάζοντας λογαριασμένος λογιασμένος λογικευμένος
 λογογραφώντας λογοδοσμένος λογοδοτημένος λογοκλοπώντας λογοκρίνοντας
 λογοπαικτώντας λογοφερμένος λογχισμένος λοιδορημένος λοξεμένος λουλουδιασμένος
 λουσαρισμένος λουσμένος λουστραρισμένος λυγισμένος λυγώντας λυμένος
 λυπημένος λυσσασμένος λυσσώντας λυτρωμένος λωβιασμένος λωλαμένος μαγαρισμένος
 μαγειρευμένος μαγεμένος μαγκανισμένος μαγκεμένος μαγκωμένος μαγνητισμένος
 μαγνητοσκοπώντας μαγνητοφωνημένος μαδημένος μαζεμένος μαζικοομοιογενοποιημένος
 μαζωμένος μαθαίνοντας μαθημένος μαθητεύοντας μαθητιώντας μαινόμενος
 μακελεμένος μακιγιαρισμένος μακροθυμώντας μακρολογώντας μακρυσμένος
 μαλακώνοντας μαλαματοκαπνισμένος μαλαμοκαπνισμένος μαλλιασμένος
 μαλωμένος μανιασμένος μανισμένος μανιωμένος μανουβραρισμένος μανταλωμένος
 μαντατεμένος μαντεμένος μαντιλοδεμένος μαντρισμένος μαντρωμένος μαξιλαρωμένος
 μαραζιασμένος μαραζωμένος μαραμένος μαργωμένος μαριναρισμένος μαρκαλισμένος
 μαρκαρισμένος μαρμαρωμένος μαρξίζων μαρσαρισμένος μαρτυρημένος μαρτυρώντας
 μασκαρεμένος μασουλημένος μασουλισμένος μασουλώντας μασουρισμένος μαστιγωμένος
 μαστουριάζοντας μαστουρωμένος ματαιοδοξώντας ματαιολογημένος ματαιολογώντας
 ματαιοφρονώντας ματαιωμένος ματιασμένος ματισμένος ματοβαμμένος ματοκυλισμένος
 μαυλισμένος μαυρισμένος μαυρολογημένος μαυρολογώντας μαυροφορημένος
 μαχαιρωμένος μαχόμενος μαϊναρισμένος μεγαλαυχώντας μεγαληγορώντας
 μεγαλοποιημένος μεγαλοποιώντας μεγαλοπραγμονώντας μεγαλορρημονημένος
 μεγαλουργώντας μεγαλοφρονώντας μεγαλωμένος μεγαλώνοντας μεγεθυμένος
 μεθερμηνεμένος μεθοδευμένος μεθοκοπώντας μεθορμισμένος μεθυσμένος μεθώντας
 μειονεκτώντας μειονοψηφώντας μειοψηφών μειοψηφώντας μειωμένος μειώνοντας
 μελανειμονώντας μελανηφορώντας μελανιασμένος μελανωμένος μελετημένος
 μελοδραματοποιώντας μελοποιημένος μελοποιώντας μελωδημένος μελωδώντας
 μεμονωμένος μεοψηφών μερακλωμένος μερεμένος μερισμένος μεροληπτώντας μερωμένος
 μεσουρανώντας μεστωμένος μεσώντας μεταβαλλόμενος μεταβαπτισμένος
 μεταβλημένος μεταβολισμένος μεταγγισμένος μεταγλωττισμένος μεταγραμμένος
 μεταδιδόμενος μεταδομένος μετακαλώντας μετακινημένος μετακλημένος
 μεταλλαγμένος μεταλλευμένος μεταμελημένος μεταμισθωμένος μεταμορφωμένος
 μετανιωμένος μετανοημένος μεταπεισμένος μεταπηδώντας μεταπλασμένος
 μεταπουλημένος μεταπουλώντας μεταπωλώντας μεταρρυθμισμένος μεταρσιωμένος
 μετασταθμευμένος μεταστρατοπεδευμένος μετασχηματισμένος μεταταγμένος
 μετατοπισμένος μετατρεμμένος μετατυπωμένος μεταφερμένος μεταφορτωμένος
 μεταφυτεμένος μεταφυτευμένος μεταχρωματισμένος μετεκπαιδευμένος μετεμψυχωμένος
 μετενσωματωμένος μετεξελιγμένος μετεωρισμένος μετοικισμένος μετοικώντας
 μετουσιωμένος μετοχετευμένος μετρημένος μετριασμένος μετριοφρονώντας
 μηδισμένος μηλοβολημένος μηνυμένος μηνώντας μηρυκασμένος μηχανογραφημένος
 μηχανοποιημένος μηχανοργανωμένος μηχανορραφημένος μηχανορραφώντας
 μικρογραφώντας μικρολογημένος μικρολογώντας μικροπαντρεμένος μιλημένος
 μινυρισμένος μιξαρισμένος μισανοιγμένος μισεμένος μισημένος μισθοδοτημένος
 μισοκοιμισμένος μισοτελειωμένος μνημονευμένος μνησικακώντας μνηστευμένος
 μοιρολογημένος μοιχευμένος μολαρισμένος μολεμένος μολογημένος μολογώντας
 μολυσμένος μομιοποιημένος μομιοποιώντας μοναδοποιημένος μοναρχώντας
 μονιμοποιημένος μονιμοποιώντας μονογραφημένος μονογραφώντας μονοιασμένος
 μονοπωλώντας μονταρισμένος μοντερνισμένος μονωμένος μοριοδοτούμενος
 μορφωμένος μοσκοβολώντας μοσκοπουλημένος μοστραρισμένος μοσχευμένος
 μοσχομυρισμένος μοσχοπουλημένος μουγκαμένος μουδιασμένος μουλιασμένος
 μουνουχισμένος μουνταρισμένος μουντζαλωμένος μουντζουρωμένος μουντζωμένος
 μουσκεμένος μουσουργώντας μουστωμένος μουτζουρωμένος μουτρωμένος μουχλιασμένος
 μοχλεμένος μοχτώντας μπαγδατισμένος μπαγιατεμένος μπαγλαρωμένος μπαζωμένος
 μπαλσαμωμένος μπαλωμένος μπαμπακιασμένος μπαμπουλωμένος μπανιαρισμένος
 μπανταρισμένος μπαρκαρισμένος μπαρουτιασμένος μπαρουτοκαπνισμένος
 μπαταλεμένος μπαταρισμένος μπατιρημένος μπατιρισμένος μπατσισμένος
 μπαϊλντισμένος μπεγλερώντας μπεζερισμένος μπερδεμένος μπερμπαντεμένος
 μπιζαρισμένος μπιμπιλωμένος μπιστεμένος μπιτισμένος μπλαβιασμένος
 μπλεγμένος μπλοκαρισμένος μπλοφαρισμένος μπογιαντισμένος μπογιασμένος
 μποδισμένος μπολιασμένος μποσκαρισμένος μποτιλιαρισμένος μπουγαδιασμένος
 μπουκεταρισμένος μπουκωμένος μπουμπουκιασμένος μπουρδουκλωμένος
 μπουσουλώντας μπουχτισμένος μποϊκοταρισμένος μποϋκοταρισμένος μυζώντας
 μυθιστοριογραφημένος μυθιστοριογραφώντας μυθοβατώντας μυθογραφημένος
 μυθολογημένος μυθολογώντας μυθοποιημένος μυκτηρισμένος μυξιασμένος μυρισμένος
 μυρμηκιασμένος μυρμηκιώντας μυρωμένος μυσταγωγημένος μυσταγωγώντας
 μυτισμένος μωλωπισμένος μωραμένος μωρολογημένος νανουρισμένος ναρκισσεμένος
 ναρκοθετώντας ναρκωμένος ναυαγισμένος ναυλωμένος ναυλώνοντας ναυμαχώντας
 ναυπηγώντας ναυτολογημένος ναυτολογώντας νεκραναστημένος νεκροστολισμένος
 νεκρωμένος νεοαναπτυσσόμενος νεοδιορισμένος νεοεισερχόμενος
 νεροβρασμένος νερουλιασμένος νερωμένος νεταρισμένος νευριασμένος
 νεωλκημένος νεωλκώντας νεωτερισμένος νηνεμώντας νηπιοβαπτισμένος νηστεμμένος
 νικημένος νικώμενος νικώντας νιμμένος νογώντας νοημένος νοθευμένος
 νοικοκυρεμένος νομαρχώντας νοματισμένος νομιμοποιημένος νομοθετημένος
 νοσηλευμένος νοσηλευόμενος νοσηλεύοντας νοστιμισμένος νοσφισμένος νοσώντας
 νουθετημένος νταβραντισμένος νταγιαντισμένος νταγιαντώντας νταντεμένος
 ντελαλημένος ντελαλώντας ντεραπαρισμένος ντερλικώνοντας ντοκουμενταρισμένος
 ντουμανιασμένος ντουμπλαρισμένος ντουφεκισμένος ντουχιουντισμένος
 ντυμένος νυκτοπορημένος νυκτοπορώντας νυμφευμένος νυσταγμένος νυφοστολισμένος
 νυχτοκοπώντας νυχτοπερπατημένος νυχτοπερπατώντας νυχτωμένος ξαγκιστρωμένος
 ξαγορευμένος ξαγρυπνημένος ξαγρυπνισμένος ξακρισμένος ξαλαφρωμένος
 ξαλμυρισμένος ξαμολημένος ξαμολώντας ξαναβαμμένος ξαναβγαλμένος ξαναβρασμένος
 ξαναγραμμένος ξαναγυρισμένος ξαναγυρνώντας ξαναδοκιμασμένος ξαναειπωμένος
 ξαναζωντανεμένος ξανακαμωμένος ξανακουσμένος ξανακτυπώντας ξανακυλώντας
 ξαναμιλημένος ξαναμμένος ξαναμωραμένος ξανανθισμένος ξανανιωμένος
 ξαναπαντρεμένος ξαναπαρμένος ξαναπερασμένος ξαναπεσμένος ξαναπιασμένος
 ξαναρχινισμένος ξαναρχινώντας ξαναρχισμένος ξαναρωτημένος ξανασμιγμένος
 ξαναφορεμένος ξαναφτιαγμένος ξαναχτισμένος ξαναχτυπημένος ξαναχτυπώντας
 ξανεμισμένος ξανθισμένος ξανοιγμένος ξαπολνώντας ξαπολώντας ξαποσταλμένος
 ξαραχνιασμένος ξαργώντας ξαρματωμένος ξαρμυρισμένος ξαρραβωνιασμένος ξασμένος
 ξαστερωμένος ξαστοχώντας ξαφνιασμένος ξαφρισμένος ξεβαμμένος ξεβασκαμένος
 ξεβιδωμένος ξεβλασταρωμένος ξεβοτανισμένος ξεβουλωμένος ξεβρακωμένος
 ξεβρομισμένος ξεγαντζωμένος ξεγδαρμένος ξεγελασμένος ξεγεννημένος
 ξεγλιστρώντας ξεγνοιασμένος ξεγοφιασμένος ξεγραμμένος ξεγυμνωμένος
 ξεδεμένος ξεδιαλεγμένος ξεδιαλυμένος ξεδιπλωμένος ξεδιψασμένος ξεδιψώντας
 ξεζαλισμένος ξεζεμένος ξεζουμισμένος ξεζωμένος ξεθαμμένος ξεθαρρεμένος
 ξεθεωμένος ξεθηκαρωμένος ξεθηλυκωμένος ξεθολωμένος ξεθυμασμένος ξεθυμωμένος
 ξεκαβαλικεμένος ξεκαθαρισμένος ξεκακιωμένος ξεκαλουπωμένος ξεκαλτσωμένος
 ξεκαμωμένος ξεκαπακωμένος ξεκαπελωμένος ξεκαπιστρωμένος ξεκαπνισμένος
 ξεκαρφωμένος ξεκινημένος ξεκλειδωμένος ξεκληρισμένος ξεκλωσώντας
 ξεκοκαλίζοντας ξεκοκαλισμένος ξεκολλημένος ξεκομμένος ξεκουμπισμένος
 ξεκουρασμένος ξεκουρδισμένος ξεκουρντισμένος ξεκουτιασμένος ξεκρεμασμένος
 ξεκριμένος ξεκωλωμένος ξελαγαρισμένος ξελαιμιασμένος ξελακκωμένος
 ξελασπωμένος ξελαφρωμένος ξελεπισμένος ξελιγωμένος ξελογιασμένος
 ξεμαθημένος ξεμακρυσμένος ξεμανταλωμένος ξεμασκαλισμένος ξεματισμένος
 ξεμοναχιασμένος ξεμουδιασμένος ξεμουχλιασμένος ξεμπαρκαρισμένος ξεμπερδεμένος
 ξεμπλοκαρισμένος ξεμπρατσωμένος ξεμπροστιασμένος ξεμυαλισμένος ξεμυτισμένος
 ξεμωραμένος ξεναγούμενος ξενερισμένος ξενερωμένος ξενηλατώντας ξενισμένος
 ξενοδουλεμένος ξενοιασμένος ξενοικιασμένος ξενοκοιμισμένος ξενοραμμένος
 ξεντυμένος ξενυσταγμένος ξενυχιασμένος ξενυχτισμένος ξενυχτώντας ξεπαγιασμένος
 ξεπαραδιασμένος ξεπαραλώντας ξεπαρθενεμένος ξεπαρμένος ξεπαστρεμένος
 ξεπατωμένος ξεπεζεμένος ξεπερασμένος ξεπερνώντας ξεπεσμένος ξεπεταγμένος
 ξεπηδώντας ξεπιασμένος ξεπλανεμένος ξεπλατισμένος ξεπλεγμένος ξεπληρωμένος
 ξεποδαριασμένος ξεπορτισμένος ξεπουλημένος ξεπουλώντας ξεπουπουλιασμένος
 ξεπροβοδισμένος ξεπροβοδώντας ξεραμένος ξερασμένος ξεριζωμένος ξερνοβολώντας
 ξεροτηγανισμένος ξεσαβουρωμένος ξεσαμαρωμένος ξεσβερκιασμένος ξεσβερκωμένος
 ξεσηκωμένος ξεσκαλισμένος ξεσκαλωμένος ξεσκαρταρισμένος ξεσκατισμένος
 ξεσκεπασμένος ξεσκισμένος ξεσκλαβωμένος ξεσκολισμένος ξεσκονισμένος
 ξεσκουντημένος ξεσκουντώντας ξεσκουριασμένος ξεσκουφωμένος ξεσπαθωμένος
 ξεσποριασμένος ξεσταχυασμένος ξεστηθωμένος ξεστομισμένος ξεστουπωμένος
 ξεστρατισμένος ξεστρωμένος ξεσυννεφιασμένος ξεσυρμένος ξεσφιγμένος
 ξεσχισμένος ξεταπωμένος ξετεντωμένος ξετιμώντας ξετιναγμένος ξετρελαμένος
 ξετσιπωμένος ξετυλιγμένος ξευτελισμένος ξεφανερωμένος ξεφιτιλισμένος
 ξεφορμαρισμένος ξεφορτωμένος ξεφουρνισμένος ξεφουσκωμένος ξεφραγμένος
 ξεφτισμένος ξεφτώντας ξεφυλλισμένος ξεφυσώντας ξεφυτρωμένος ξεφωνημένος
 ξεχασμένος ξεχειλισμένος ξεχειλωμένος ξεχειμασμένος ξεχειμωνιασμένος
 ξεχολιασμένος ξεχορταριασμένος ξεχρεωμένος ξεχυμένος ξεχωμένος ξεχωρισμένος
 ξεψαρωμένος ξεψαχνισμένος ξεψυχισμένος ξεψυχώντας ξηγημένος ξηγώντας ξηλωμένος
 ξημερωμένος ξηραμένος ξιδιασμένος ξιπασμένος ξιφομαχώντας ξοδεμένος
 ξολοθρεμένος ξομολογημένος ξομολογώντας ξομπλιασμένος ξουραφισμένος ξοφλημένος
 ξυλιασμένος ξυλισμένος ξυλογραφημένος ξυλογραφώντας ξυλοκοπημένος ξυλουργώντας
 ξυμένος ξυπνημένος ξυραφισμένος ξυρισμένος ξυσμένος ξυστρισμένος ογκωμένος
 οδυρμένος οζονισμένος οζοντισμένος οιακισμένος οικειοποιημένος οικειωμένος
 οικισμένος οικοδομημένος οικοδομώντας οικοκυρεμένος οικονομημένος
 οικοπεδοποιώντας οιστρηλατώντας οιωνισμένος οκνώντας ολιγοστεμένος
 ολολυσμένος ομαδοποιημένος ομαδοποιώντας ομαλισμένος ομαλοποιημένος ομιλημένος
 ομογνωμονώντας ομοδοξώντας ομοιασμένος ομοιοκαταληκτώντας ομοιοκαταληχτώντας
 ομολογημένος ομολογούμενος ομονοώντας ομοσιτώντας ομοφηφώντας ομοφρονώντας
 ομφαλοσκοπώντας ονειδισμένος ονειρεμένος ονειριασμένος ονειροβατώντας
 ονομασμένος ονοματισμένος ονοματοθετώντας ονοματοποιημένος ονοματοποιώντας
 οξειδωμένος οξυγονωμένος οξυγονώντας οξυμένος οξυτονώντας οπαλισμένος
 οπισθοδρομώντας οπλισμένος οπλομαχώντας οπτασιασμένος οραματισμένος
 οργιασμένος οργισμένος οργωμένος οργώντας ορειχαλκωμένος ορθιασμένος
 ορθογραφώντας ορθοποδώντας ορθοτομώντας ορθοτονώντας ορθοφρονώντας ορθωμένος
 οριοθετημένος οριστικοποιημένος οριστικοποιώντας ορκισμένος ορκοδοτώντας
 ορμημένος ορμηνεμένος ορμισμένος οροθετημένος οροθετώντας ορτσαρισμένος
 ορφανισμένος οσμισμένος οστεοενσωματούμενος οστεωμένος ουρανοβατώντας
 ουσιαστικοποιημένος οφειλόμενος οχλοκρατημένος οχυρωμένος ούσα οὑ πάσχων
 πίνοντας παίρνοντας παγιδευμένος παγιωμένος παγοδρομώντας παγουδιώντας
 παθημένος παθιασμένος παθών παιγμένος παιδαγωγημένος παιδαγωγώντας παιδεμένος
 παιδιαρισμένος παιδοκομώντας παιδοποιημένος παιδοποιώντας παιζογελώντας
 πακεταρισμένος πακτωμένος παλαβωμένος παλαμισμένος παλαντζαρισμένος παλεμένος
 παλινδρομώντας παλιννοστώντας παλινωδώντας παλιωμένος παλλόμενος παλουκωμένος
 πανηγυρισμένος πανιασμένος πανικοβλημένος παντρολογημένος παντρολογώντας
 παπαριασμένος παράγοντας παρέχοντας παραβαμμένος παραβιασμένος παραγγελμένος
 παραγερασμένος παραγερνώντας παραγινωμένος παραγιομισμένος παραγκωνισμένος
 παραγραμμένος παραγραμματισμένος παραγόμενος παραδαρμένος παραδεδομένος
 παραδιαβασμένος παραδομένος παραδουλεμένος παραειπωμένος παραζαλισμένος
 παραθαρρυμένος παραθεμένος παραθερισμένος παραθερμασμένος παραθυμωμένος
 παραιτούμενος παρακάμπτοντας παρακαθήμενος παρακαλεσμένος παρακαλώντας
 παρακατατεθειμένος παρακεντημένος παρακεντώντας παρακινδυνευμένος
 παρακλαδεμένος παρακμασμένος παρακοιμισμένος παρακρατημένος παρακρατούμενος
 παρακωλυμένος παραληφθείς παραλλαγμένος παραλληλισμένος παραλογιασμένος
 παραλυμένος παραμακιγιαρισμένος παραμακρεμένος παραμεγαλωμένος παραμελημένος
 παραμελώντας παραμερισμένος παραμετροποιώντας παραμιλώντας παραμορφωμένος
 παραμυθολογώντας παρανοημένος παρανομασμένος παρανομιασμένος παρανομώντας
 παρανυσταγμένος παραξενεμένος παραξενιασμένος παραξηλωμένος παραξοδεμένος
 παραπεισμένος παραπεσμένος παραπεταμένος παραπετώντας παραπικραμένος
 παραπλέοντας παραπλανημένος παραπλανώντας παραπληροφορημένος παραπληροφορώντας
 παραπονεμένος παραπονούμενος παραριγμένος παρασιτώντας παρασιωπώντας
 παρασπονδώντας παραστημένος παραστρατημένος παραστρατώντας παρασυρμένος
 παρατεντωμένος παρατεταγμένος παρατεταμένος παρατημένος παρατηρηθείς
 παρατιμονιασμένος παρατραβηγμένος παρατρεγμένος παρατρεχάμενος παρατριμμένος
 παρατυπώντας παραφαγωμένος παραφθαρμένος παραφορτωμένος παραφουσκωμένος
 παραφρονημένος παραφυλαγμένος παραφωνώντας παραχαραγμένος παραχαϊδεμένος
 παραχωμένος παραχωρήσιμος παραχωρημένος παραχωρώντας παραψημένος
 παρειλημμένος παρεισαγμένος παρελθοντολογημένος παρελθοντολογώντας
 παρεμποδισμένος παρεννοημένος παρεννοώντας παρενοχλημένος παρεξηγημένος
 παρερμηνευμένος παρεστώς παρετυμολογημένος παρευρισκόμενος παρεχόμενος
 παρηκμασμένος παριστάμενος παρκαρισμένος παρκεταρισμένος παροικημένος
 παρομοιασμένος παρομοιωμένος παρονομασμένος παροξυμμένος παροπλισμένος
 παρορμώντας παρορώντας παρουσιάζοντας παρουσιασμένος παροχετευμένος
 παρωδημένος παρωθημένος παρωθώντας παρωχημένος πασαλειμμένος πασαρισμένος
 πασσαλωμένος παστεριωμένος παστρεμένος παστωμένος πασχισμένος παταγμένος
 πατριαρχώντας πατροναρισμένος πατσισμένος παυμένος παφλασμένος παχαίνοντας
 παχτωμένος πεδικλωμένος πεζεμένος πεζογραφώντας πεζοδρομημένος πεζολογώντας
 πεζοπορώντας πεθυμημένος πεθυμώντας πειθαναγκασμένος πειθαρχημένος
 πεινασμένος πεινώντας πειραγμένος πειραματισμένος πειρατευμένος πεισμένος
 πεισμωμένος πελαγισμένος πελαγοδρομώντας πελαγωμένος πενηνταρισμένος
 πενθηφορώντας πενθώντας πενταπλασιασμένος πεντοβολώντας πεπαιδευμένος
 πεπεισμένος πεπερασμένος πεπλατυσμένος πεπραγμένος πεπυκνωμένος περαιωμένος
 περεχώντας περηφανεμένος περιαλειμμένος περιαρπαγμένος περιαυτολογώντας
 περιβάλλων περιβεβλημένος περιβρεγμένος περιγεγραμμένος περιγελώντας
 περιδεδεμένος περιδεμένος περιδινώντας περιδρομιάζοντας περιελιγμένος
 περιζωσμένος περιθωριοποιημένος περικαλυμμένος περικλαδεμένος περικλεισμένος
 περικομμένος περικοσμημένος περικοσμώντας περικυκλωμένος περιλουσμένος
 περιμαζεμένος περιμαζωγμένος περιμαντρωμένος περιοδεύων περιορίζοντας
 περιπαιγμένος περιπατημένος περιπεπλεγμένη περιπεπλεγμένο περιπεπλεγμένος
 περιπλανώμενος περιπλεγμένος περιποιημένος περιποιώντας περιπτυγμένος
 περισκοπημένος περισκοπώντας περιστεφανωμένος περιστοιχισμένος περιστρεμμένος
 περισφιγμένος περισχοινισμένος περισωσμένος περιτειχισμένος περιτετμημένος
 περιτρεγμένος περιτριγυρισμένος περιτυλιγμένος περιυβρισμένος περιφερόμενος
 περιφραγμένος περιφρονημένος περιφρονώντας περιφρουρημένος περιχαραγμένος
 περιχρισμένος περιχρυσωμένος περιχυμένος περιχώντας περνώντας περπατημένος
 περώντας πετάμενος πεταγμένος πεταλουδισμένος πεταλωμένος πεταμένος
 πετούμενος πετροβολημένος πετροβολώντας πετρωμένος πετσιασμένος
 πετσοκομμένος πετσωμένος πετώντας πεφυσιωμένος πεφωτισμένος πηγασμένος
 πηδαλιουχώντας πηδημένος πηλαλώντας πηλοβατημένος πηλοβατώντας πιάνοντας
 πιασμένος πιδακισμένος πιθανολογημένος πιθηκισμένος πιθυμημένος πιθυμώντας
 πικαρισμένος πικρισμένος πικροκαρδισμένος πιλαλώντας πιλατεμένος
 πιλοφορημένος πιλοφορώντας πιξελιασμένος πιπερισμένος πιπερωμένος πιπιλημένος
 πιπιλώντας πιπισμένος πιρουνιασμένος πισσωμένος πιστεύοντας πιστοδοτημένος
 πιστολισμένος πιστοποιημένος πιστοποιώντας πιστοχρεωμένος πιστωμένος
 πισωδρομώντας πιτηδευμένος πιτσιλημένος πιτσιλισμένος πιτσιλώντας πλέοντας
 πλαγιοδετώντας πλαγιοδιποδισμένος πλαγιοδρομώντας πλαγιοποδισμένος
 πλαγιοφυλακώντας πλαισιωμένος πλακοστρωμένος πλακωμένος πλαλώντας πλανισμένος
 πλαντώντας πλανώντας πλασαρισμένος πλασμένος πλαστικοποιημένος
 πλαστογραφώντας πλαστοπροσωπημένος πλαστοπροσωπώντας πλαστουργώντας
 πλατειασμένος πλατσουρισμένος πλατυσμένος πλεγμένος πλειοδοτημένος
 πλειοψηφών πλειοψηφώντας πλειστηριασμένος πλεονασμένος πλεονεκτώντας
 πλευρισμένος πλευριτωμένος πλευροκοπημένος πλευροκοπώντας πληγείς πληγιασμένος
 πληγωμένος πληθυσμένος πληκτρολογημένος πληκτρολογώντας πλημμυρισμένος
 πληροφορημένος πληροφορούμενος πληροφορώντας πληρωμένος πληρώνοντας
 πληττόμενος πλιατσικολογημένος πλινθοδομημένος πλισαρισμένος πλοηγημένος
 πλοιαρχημένος πλοιαρχώντας πλουμισμένος πλουτισμένος πλουτώντας πλυμένος
 πνευστιώντας πνιγμένος ποδεμένος ποδισμένος ποδοβολώντας ποδοπατημένος
 ποθημένος ποθούμενο ποιηθέν ποιηθείς ποιηθείς ποιηθεῖσα ποιημένος
 ποιμεναρχώντας πολεμημένος πολεοδομημένος πολιορκημένος πολιτευμένος
 πολιτικοποιημένος πολιτογραφημένος πολιτογραφώντας πολλαπλασιασμένος
 πολυαγαπημένος πολυαναμενόμενος πολυβραβευμένος πολυδιαβασμένος πολυδουλεμένος
 πολυμεταγγιζόμενος πολυμιλημένος πολυξοδιασμένος πολυπαθημένος πολυπικραμένος
 πολυσυζητημένος πολυταξιδεμένος πολυτεντωμένος πολυχρονεμένος πολυχρονισμένος
 πομπευμένος πομπιασμένος πονηρεμένος πονοκεφαλιασμένος πονοκεφαλώντας
 ποντισμένος ποντοπορώντας πορευόμενος πορθημένος πορθώντας πορισμένος
 πορνογραφώντας πορπατημένος πορφυρισμένος ποσταρισμένος ποτίζοντας ποτισμένος
 πουλημένος πουμωμένος πουντιασμένος πουριασμένος πράττων πρέπων πραγματευμένος
 πραγματωμένος πρασινισμένος πραϋμένος πρεζαρισμένος πρεσαρισμένος πρησμένος
 πριονισμένος προαγγελμένος προαγορασμένος προαλειμμένος προαναγγελμένος
 προαναφερθής προαναφερμένος προαναφερόμενος προαναφλεγμένος προαπαγορευμένος
 προαπαντώντας προαποφασισμένος προασκώντας προασπισμένος προασφαλισμένος
 προαχθείς προβάλλοντας προβαλλόμενος προβαρισμένος προβεβλημένος προβιβασμένος
 προβληματισμένος προβοδισμένος προβοδωμένος προβοκαρισμένος προγευματισμένος
 προγραμμένος προγραμματισμένος προγυμνασμένος προδιαγεγραμμένος
 προδιατυπωμένος προδικασμένος προδομένος προειδοποιημένος προεικασμένος
 προεισπραγμένος προεκλεγμένος προεκτεταμένος προεκτυπωμένος προεμβασμένος
 προεξάρχων προεξέχων προεξοφλημένος προεξοφλώντας προεπιλεγμένος προερχόμενος
 προετοιμασμένος προηγμένος προθερμασμένος προθυμοποιημένος προικισμένος
 προικοθηρώντας προκαθορισμένος προκαλυμμένος προκαλώντας προκαταβεβλημένος
 προκατασκευασμένος προκατειλημμένος προκατεργασμένος προκείμενος προκηρυγμένος
 προκινδυνευμένος προκομμένος προκριμένος προκύπτων προλογισμένος προμαντεμένος
 προμελετημένος προμελετώντας προμηθευμένος προμηνώντας προμισθωμένος
 προξενεμένος προοδευμένος προοιμιασμένος προοιωνισμένος προορισμένος
 προπαγανδισμένος προπαιδευμένος προπαρασκευασμένος προπερισπώμενος
 προπηλακισμένος προπλασμένος προπληρωμένος προπλυμένος προπονημένος
 προπονώντας προπορευμόμενος προπορευόμενος προσήκων προσανατολισμένος
 προσαρτημένος προσαυξημένος προσαχθείς προσγειωμένος προσδεμένος
 προσδιορισμένος προσδοκώμενος προσδοσμένος προσεγγισμένος προσεγμένος
 προσελκυσμένος προσεπικαλώντας προσεπικυρωμένος προσεταιρισμένος προσηγμένος
 προσηλιασμένος προσηλυτισμένος προσηλωμένος προσημειωμένος προσθαλασσωμένος
 προσιδιασμένος προσκεκλημένος προσκολλημένος προσκολλώντας προσκομισμένος
 προσκυνώντας προσκυρωμένος προσλιμενισμένος προσμαρτυρημένος προσμαρτυρώντας
 προσμετρημένος προσμετρώντας προσμοιασμένος προσομοιασμένος προσονομασμένος
 προσπαθώντας προσπελασμένος προσπερασμένος προσποιημένος προσποιούμενος
 προσσεληνωμένος προσταγμένος προστατευμένος προστατευόμενος προστιμαρισμένος
 προσυμφωνημένος προσυπογεγραμμένος προσυπογραμμένος προσφέροντας προσφερμένος
 προσχηματισμένος προσχωμένος προσχωρώντας προσωπογραφώντας προσωποκρατημένος
 προσωποληπτώντας προσωποποιημένος προσωποποιώντας προταγμένος προταθείς
 προτεινόμενος προτειχισμένος προτελευτώντας προτιμολογημένος προτιμολογώντας
 προτιμώντας προτονισμένος προφασισμένος προφερμένος προφητεμένος προφυλαγμένος
 προχειρισμένος προχειρογραμμένος προχειρολογώντας προχρονολογημένος
 προωθημένος προωθούμενος προϊδεασμένος προϊδωμένος προϊών προϋπαντώντας
 προϋπογεγραμμένος προϋπολογισμένος πρυματσαρισμένος πρυμνοδετημένος
 πρυτανευμένος πρωταγωνιστώντας πρωταρχινισμένος πρωταρχισμένος πρωτεύων
 πρωτοβγαλμένος πρωτογεννημένος πρωτογεννώντας πρωτογνωρισμένος
 πρωτοκαθισμένος πρωτοκολλημένος πρωτοκολλώντας πρωτολεγμένος
 πρωτομιλώντας πρωτοπιασμένος πρωτοστατώντας πρωτοτυπώντας πρωτοφαγωμένος
 πρωτοφορώντας πτερυγισμένος πτερωμένος πτοημένος πτυσμένος πτυσσόμενος
 πτωχεύσας πτωχυμένος πυγμαχώντας πυκνοφυτεμένος πυκνωμένος πυορροώντας
 πυργωμένος πυροβολημένος πυροδοτώντας πυρπολημένος πυρπολώντας πυρωμένος
 πωματισμένος πωρωμένος ρέων ρίχνοντας ραβδισμένος ραβδομαχώντας ραβδοσκοπώντας
 ραγισμένος ραγολογώντας ραδιουργώντας ραθυμώντας ρακοφορεμένος ρακοφορώντας
 ραμφισμένος ραντίζοντας ραντισμένος ραπισμένος ραφιναρισμένος ραχατεμένος
 ρεγουλαρισμένος ρεζιλεμένος ρεκλαμαρισμένος ρελιασμένος ρεμβάζοντας
 ρεσταρισμένος ρετουσαρισμένος ρευστοποιημένος ρευστοποιούμενος ρευστοποιώντας
 ρεφενισμένος ρημαγμένος ρημωμένος ρητινευμένος ρητινωμένος ρητορευμένος
 ριγωμένος ριζοβολημένος ριζοβολώντας ριζοδοντιασμένος ριζολογώντας
 ριζωμένος ρικνωμένος ρινισμένος ριπισμένος ρισκαρισμένος ριψοκινδυνευμένος
 ρογιασμένος ροδισμένος ροδοκοκκινισμένος ροκανισμένος ρολαρισμένος
 ρουφηγμένος ροφώντας ρυασμένος ρυθμισμένος ρυμοτομημένος ρυμοτομούμενος
 ρυμουλκημένος ρυμουλκούμενος ρυμουλκώντας ρυπαρογραφώντας ρυπασμένος
 ρωθωνισμένος ρωτημένος σαβανωμένος σαβουρωμένος σαγηνεμένος σαγμένος
 σακιασμένος σακουλεμένος σακουλιασμένος σαλαγώντας σαλεμένος σαλιασμένος
 σαλπαρισμένος σαλταρισμένος σαμαρωμένος σαμποταρισμένος σανιδωμένος σαπισμένος
 σαπωνοποιώντας σαραβαλιασμένος σαρακιασμένος σαρανταρισμένος σαραντισμένος
 σαρκωμένος σαρωμένος σαστισμένος σατιναρισμένος σατιρισμένος σαφηνισμένος
 σαϊτεμένος σβήνοντας σβαναρισμένος σβαρνισμένος σβησμένος σβολιασμένος
 σεγκονταρισμένος σεισμένος σεκλεντισμένος σεκλετισμένος σεκονταρισμένος
 σελεμιασμένος σελεμισμένος σεληνιασμένος σελιδοποιημένος σελιδοποιώντας
 σελωμένος σεμνολογώντας σεντονιασμένος σεντραρισμένος σερβιρισμένος
 σερμένος σεσημασμένος σεταρισμένος σηκωμένος σημαίνων σημαδεμένος
 σημασμένος σηματοδοτημένος σηματοδοτώντας σηματολογώντας σημειωμένος
 σιαγμένος σιαλωμένος σιασμένος σιγοβρασμένος σιγονταρισμένος σιγοτραγουδημένος
 σιγουρεμένος σιγοψιθυρισμένος σιδερωμένος σιμωμένος σιροπιασμένος σιτεμένος
 σιχαμένος σιωπώντας σκαλισμένος σκαλωμένος σκαμμένος σκαμπιλισμένος
 σκανδαλοθηρώντας σκανδαλολογώντας σκανταγιαρισμένος σκανταλισμένος σκαπετώντας
 σκαριφώντας σκαρταρισμένος σκαρτεμένος σκαρφαλωμένος σκαρφισμένος σκαρωμένος
 σκατωμένος σκαφιδιασμένος σκαφιδωμένος σκεβρωμένος σκεδασμένος σκεπασμένος
 σκερτσαρισμένος σκευασμένος σκηνογραφώντας σκηνοθετημένος σκηνώντας σκιαγμένος
 σκιαμαχώντας σκιασμένος σκιρτώντας σκισμένος σκιτσαρισμένος σκλαβωμένος
 σκληραγωγώντας σκολασμένος σκολιώντας σκολνώντας σκολοπισμένος σκονισμένος
 σκορπώντας σκοταδιασμένος σκοτεινιασμένος σκοτιδιασμένος σκοτισμένος
 σκουληκιασμένος σκουντουφλιασμένος σκουντουφλώντας σκουντώντας σκουπισμένος
 σκουριασμένος σκουφωμένος σκυθρωπασμένος σκυλεμένος σκυλιασμένος
 σκυλοφαγωμένος σκυμμένος σκυροδετώντας σκωληκιώντας σμαλτωμένος σμιγμένος
 σμπαραλιασμένος σνομπαρισμένος σοβαντισμένος σοβατισμένος σοβενταρισμένος
 σοδομισμένος σοκαρισμένος σολιασμένος σολοικισμένος σοναρισμένος σοροπιασμένος
 σουβαντισμένος σουβλισμένος σουλαντώντας σουλουπωμένος σουμαρισμένος
 σουπαρισμένος σουραυλισμένος σουρισμένος σουρμένος σουρομαδημένος
 σουρομαλλιασμένος σουρουπωμένος σουρτουκευμένος σουρωμένος σουσουμιασμένος
 σουφρωμένος σοφαρισμένος σοφιλιασμένος σπαζοκεφαλιασμένος σπαραγμένος
 σπαργώντας σπαρμένος σπαρταρισμένος σπασμένος σπαταλημένος σπεκουλαρισμένος
 σπερμολογώντας σπιθισμένος σπιθοβολώντας σπικαρισμένος σπιλωμένος
 σπινθηροβολώντας σπιουναρισμένος σπιρουνιασμένος σπιρουνισμένος σπιτωμένος
 σπληνιασμένος σπογγισμένος σποριασμένος σπουδαγμένος σπουδαιολογημένος
 σπουδαρχώντας σπρωγμένος σπυριασμένος σταβλισμένος σταδιοδρομημένος
 σταθεροποιημένος σταθμευμένη σταθμευμένος σταθμισμένος σταλαγμένος σταλμένος
 σταμπαρισμένος στανιάροντας στασιασμένος σταυροκοπημένος σταυροφορώντας
 σταφιδιασμένος σταχολογημένος σταχολογώντας σταχτωμένος σταχυολογημένος
 σταχωμένος στεγανοποιημένος στεγασμένος στειλιαρωμένος στειμμένος στειρεμένος
 στειροποιώντας στεκάμενος στεκούμενος στελεχωμένος στεναχωρημένος στενεμένος
 στενογραφώντας στενοχωρεμένος στενοχωρημένος στερεμένος στερεοποιημένος
 στερεωμένος στερημένος στεριωμένος στερφεμένος στεφανηφορώντας στεφανωμένος
 στηθοσκοπώντας στηλιτευμένος στημένος στημονιασμένος στηριγμένος
 στιλβωμένος στιλιζαρισμένος στιμαρισμένος στιχουργώντας στοιβαγμένος
 στοιχειοθετώντας στοιχειωμένος στοιχισμένος στοιχώντας στοκαρισμένος
 στολοδρομώντας στομαχιασμένος στομφασμένος στομωμένος στοπαρισμένος
 στουμπισμένος στουμπωμένος στουπωμένος στοχασμένος στοχοπροσηλωμένος
 στρίβοντας στραβοκοιταγμένος στραβολαιμιασμένος στραβομουτσουνιασμένος
 στραβοπατώντας στραβωμένος στραγγαλισμένος στραγγιγμένος στραμμένος
 στραπατσαρισμένος στραταρισμένος στρατευμένος στρατιωτικοποιημένος
 στρατοπεδευμένος στρατωνισμένος στρεβλωμένος στρεσαρισμένος στριμμένος
 στριμωγμένο στριμωγμένος στριφογυρισμένος στριφογυρνώντας στριφωμένος
 στρογγυλεμένος στρογγυλοκαθισμένος στρογγυλωμένος στρωμένος στυλωμένος
 στυπωμένος συγγεγραμμένος συγγενευμένος συγκαλεσμένος συγκαλυμμένος συγκαμένος
 συγκατανευμένος συγκαταριθμώντας συγκαταταγμένος συγκατηγορούμενος
 συγκεκαλυμμένος συγκεκλιμένος συγκεκομμένος συγκεκριμένος συγκερασμένος
 συγκληρονομώντας συγκλονισμένος συγκολλημένος συγκολλώντας συγκομισμένος
 συγκρατούμενος συγκρατώντας συγκριμένος συγκρινόμενος συγκροτημένος
 συγκρουόμενος συγκυβερνημένος συγκυβερνώντας συγκυμαινόμενος συγυρισμένος
 συγχρονισμένος συγχρωτισμένος συγχωνευμένος συγχωρημένος συδαυλισμένος
 συζητημένος συζητούμενος συζητώντας συζώντας συκοφαντημένος συλημένος
 συλλεγμένος συλλειτουργώντας συλώντας συμβαλλόμενη συμβαλλόμενος συμβεβλημένος
 συμβιβασμένος συμβολαιογραφώντας συμβολισμένος συμβουλευμένος συμμαζεμένος
 συμμερισμένος συμμετέχων συμμορφωμένος συμπάσχων συμπίπτων συμπαγιωμένος
 συμπαραταγμένος συμπαρομαρτώντας συμπεριλαμβανημένος συμπεριλαμβανόμενος
 συμπιασμένος συμπιλώντας συμπλεγμένος συμπληρωμένος συμπολεμώντας
 συμπονώντας συμποσιασμένος συμπραγμένος συμπρωταγωνιστώντας συμπτυγμένος
 συμπώντας συμφέρων συμφαγωμένος συμφεροντολογώντας συμφιλιωμένος συμφοιτώντας
 συμφραζόμενος συμψηφισμένος συναγελασμένος συναγωνισμένος συναθροισμένος
 συναιρώντας συναισθανόμενος συνακολουθώντας συναλλαγμένος συναντημένος
 συναπαντώντας συναπαρτισμένος συναποτελώντας συναρθρωμένος συναριθμώντας
 συναρμολογώντας συναρμοσμένος συναρπαγμένος συναρπασμένος συναρτημένος
 συνασπισμένος συναχωμένος συνδέοντας συνδαυλισμένος συνδεδεμένος συνδειπνώντας
 συνδεσμευμένος συνδιαλεγόμενος συνδιαλλαγμένος συνδικαλισμένος συνδικασμένος
 συνεγερμένος συνεδριασμένος συνειδητοποιημένος συνεισπραττόμενος συνεκτιμώντας
 συνεκφωνώντας συνεννοημένος συνεντευξιαζόμενος συνενωμένος συνεξετασμένος
 συνεπαρμένος συνεπτυγμένος συνεργαζόμενος συνεργασμένος συνεργώντας
 συνεστραμμένος συνεταιρισμένος συνετισμένος συνεχισμένος συνηγμένος
 συνηχούμενος συνηχώντας συνθεμένος συνθηματολογώντας συνθλιμμένος συνιζημένος
 συνοδευμένος συνοδευόμενος συνοδοιπορώντας συνοικισμένος συνοικώντας
 συνομολογηθείς συνομολογημένος συνομολογώντας συνονθυλευμένος συνορεμένος
 συνοφρυωμένος συνοψισμένος συνταγογραφημένος συνταγογραφούμενος
 συνταιριασμένος συνταξιοδοτημένος συνταραγμένος συντασσόμενος συνταυτισμένος
 συντελεσμένος συντεταγμένος συντετμημένος συντετριμμένος συντηρημένος
 συντονισμένος συντρεγμένος συντριμμένος συντροφευμένος συνυπηρετώντας
 συνυπογεγραμμένος συνυπολογισμένος συνυφασμένος συνωστισμένος συρμένος
 συρματοποιώντας συρραμμένος συρρικνωμένος συρρικνώνοντας συσκευασμένος
 συσπειρωμένος συσπουδασμένος συσσωματωμένος συσσωρευμένος συστήνοντας
 συσταχωμένος συστεγασμένος συστηματοποιημένος συστηματοποιώντας συστραμμένος
 συσχετισμένος συχωρεμένος συχωρνώντας σφαγιασμένος σφαγμένος σφαλισμένος
 σφαλώντας σφεντονισμένος σφεντονώντας σφετερισμένος σφηνωμένος σφιγμένος
 σφουγγαρισμένος σφουγγισμένος σφραγισμένος σφριγώντας σφυγμομετρημένος
 σφυρηλατώντας σφυριγμένος σφυροκοπημένος σφυροκοπώντας σφύζων σχεδιαγραφώντας
 σχεδιογραφώντας σχετισμένος σχηματισμένος σχηματοποιημένος σχηματοποιώντας
 σχοινοβατώντας σχολασμένος σχολιασμένος σχολνώντας σωληνωμένος σωμένος
 σωπασμένος σωρευμένος σωριασμένος σωροβολιασμένος σωσμένος σωφρονισμένος
 ταγισμένος ταγκισμένος ταιριασμένος τακτοποιημένος ταλαιπωρημένος ταλανισμένος
 ταλαντευόμενος ταμένος ταμιευμένος ταμποναρισμένος ταμπουρωμένος τανυσμένος
 ταξιδεύοντας ταξιδεύων ταξιθετημένος ταξιθετώντας ταξινομημένος ταπεινωμένος
 ταπωμένος ταραγμένος ταρακουνημένος ταρακουνώντας ταρατσωμένος ταυτισμένος
 ταυτογνωμονώντας ταυτογνωμώντας ταυτολογημένος ταυτολογώντας ταυτοποιημένος
 ταχταρισμένος ταχτοποιημένος ταχτοποιώντας ταχυδακτυλουργώντας
 ταχυδρομημένος ταχυπορημένος ταχυπορώντας ταϊσμένος τεζαρισμένος τεθλασμένος
 τειχομαχημένος τειχομαχώντας τεκμηριωμένος τεκνοποιώντας τελειοποιώντας
 τελετουργημένος τελετουργώντας τελευτημένος τελευτώντας τελματωμένος
 τελώντας τεμαχισμένος τεντωμένος τερατολογημένος τερατολογώντας τερηδονισμένος
 τεταμένος τετελεσμένος τετηγμένος τετμημένος τετραγωνίζοντας τετραγωνισμένος
 τετραποδισμένος τετρασυντεταγμένος τετρασυντονισμένος τετραφθοριωμένος
 τετραφωσφορυλιωμένος τετραχλωριωμένος τετριμμένος τεχνολογημένος τεχνολογώντας
 τζαμωμένος τζαρτζαρισμένος τζιριτώντας τηγανισμένος τηλεγραφημένος
 τηλεφωνημένος τηρών τηρώντας τιθασευμένος τιμαρευμένος τιμημένος τιμολογημένος
 τιμωρώντας τιμώμενος τιμώντας τιναγμένος τιτλοφορημένος τοιχισμένος
 τοιχογραφώντας τοιχογυρισμένος τοιχοδομημένος τοιχοδομώντας τοιχοκολλημένος
 τολμημένος τονισμένος τονωμένος τοξεμένος τοπιοτεχνημένος τοπογραφημένος
 τοποθετημένος τοπομαχώντας τορευμένος τορνεμένος τορπιλισμένος
 τουμπανιασμένος τουμπανισμένος τουμπαρισμένος τουρκεμένος τουρκοκρατημένος
 τουρλωμένος τουφεκισμένος τρέμοντας τρέχοντας τρίβοντας τραβατζαρισμένος
 τραβηγμένος τραβολογημένος τραβώντας τραγανισμένος τραγικοποιώντας
 τραγωδοποιημένος τραγωδοποιώντας τρακαρισμένος τραμπαλισμένος
 τρανεμένος τρανταγμένος τρανωμένος τραπεζωμένος τραταρισμένος τραυλίζοντας
 τρεκλισμένος τρελαμένος τρεμομανιασμένος τρεμοσβησμένος τρεμουλιασμένος
 τριγμένος τριγυρισμένος τριγυρνώντας τριγωνομετρημένος τριγωνομετρώντας
 τριηραρχώντας τρικυμισμένος τριμμένος τριπλασιασμένος τριποδισμένος
 τριταγωνιστώντας τριτεγγυημένος τριτευμένος τριφωσφορυλιωμένος τριχλωριωμένος
 τριχοτομώντας τρομαγμένος τρομοκρατημένος τρομοκρατώντας τρομπαρισμένος
 τροπολογώντας τροποποιημένος τροποποιώντας τροπωμένος τροφοδοτημένος
 τροχαλημένος τροχαλώντας τροχασμένος τροχισμένος τροχοδρομημένος
 τροχοπεδημένος τροχοπεδιλοδρομώντας τροχοπεδώντας τρυγημένος τρυγλοδυτώντας
 τρυπανισμένος τρυπημένος τρυπωμένος τρυφώντας τρώγοντας τσαγκρουνισμένος
 τσακωμένος τσαλαβουτημένος τσαλαβουτώντας τσαλακωμένος τσαλαπατημένος
 τσαμπουνώντας τσαπισμένος τσατισμένος τσεκαρισμένος τσεκουρωμένος τσεπωμένος
 τσιγκλώντας τσιγκουνεμένος τσιλημπουρδώντας τσιληπουρδώντας τσιλλώντας
 τσιμπλιασμένος τσιμπολογώντας τσιρλισμένος τσιρλώντας τσιτωμένος
 τσουβαλιασμένος τσουγκρανισμένος τσουγκρισμένος τσουλώντας τσουρουφλισμένος
 τυλιγαδιασμένος τυλιγμένος τυλωμένος τυμπανισμένος τυπασμένος τυποκλοπώντας
 τυπωμένος τυραγνώντας τυραννημένος τυραννισμένος τυραννώντας τυροκομημένος
 τυφεκισμένος τυφλωμένος υαλογραφημένος υαλογραφώντας υαλοποιημένος
 υβρισμένος υγραμένος υγροποιημένος υγροποιώντας υδατογραφημένος υδατογραφώντας
 υδρογονωμένος υδροδοτημένος υδροδοτώντας υδροχρωματισμένος υιοθετημένος
 υλοτομημένος υμνημένος υμνογραφημένος υμνογραφώντας υμνολογημένος υμνολογώντας
 υπάρχων υπαγμένος υπαγορευμένος υπαγόμενος υπαινιγμένος υπακούοντας
 υπαντημένος υπαντώντας υπεκμισθωμένος υπενδυμένος υπενθυμισμένος
 υπεξαιρεμένος υπεξαιρώντας υπεραγαπημένος υπεραγαπώντας υπερακοντισμένος
 υπερασπισμένος υπεραυξημένος υπερβάλλων υπερβεβλημένος υπερδιατιμημένος
 υπερεκτιμώντας υπερεκχειλισμένος υπερεντεταμένος υπερεπαρκώντας
 υπερευχαριστώντας υπερηφανευμένος υπερθεματισμένος υπερκαλυμμένος
 υπερκερώντας υπερκορεσμένος υπερμαχώντας υπερνικώντας υπερπηδώντας
 υπερπροστατευμένος υπερσιτισμένος υπερτερώντας υπερτιμημένος υπερτιμολογημένος
 υπερτιμώντας υπερυψωμένος υπερφαλαγγισμένος υπερφορτισμένος υπερφορτωμένος
 υπερχειλισμένος υπερχρεωμένος υπερχρονισμένος υπερψηφισμένος υπερψυγμένος
 υπηρετημένος υπνοβατώντας υπνωμένος υπνωτισμένος υποαπασχολημένος
 υποβαθμισμένος υποβεβλημένος υποβιβάζοντας υποβιβασμένος υποβοηθημένος
 υπογεγραμμένη υπογεγραμμένος υπογράφων υπογραμμένος υπογραμμισμένος
 υποδαυλιζόμενος υποδαυλισμένος υποδειγμένος υποδεμένος υποδηλωμένος
 υποδιαιρώντας υποδιατιμημένος υποδουλωμένος υποεκτιμημένος υποεκτιμώντας
 υποθέτοντας υποθερμασμένος υποκαιώντας υποκατεστημένος υποκεφαλαιοποιημένος
 υποκινούμενος υποκλεμμένος υποκρινόμενος υποκρουσμένος υποκρυμμένος
 υπολειτουργώντας υπολογίζοντας υπολογισμένος υπομένοντας υπομισθωμένος
 υπομοχλευμένος υπονομευμένος υποσιτισμένος υποσχόμενος υποταγμένος
 υποτιθέμενος υποτιμημένος υποτιμώντας υπουργώντας υποφέρων υποφαινόμενος
 υστερολογώντας υστερώντας υφασμένος υφιστάμενος υφισταμένη υψηλοφρονώντας
 φέρνοντας φέρων φαγουριασμένος φαγωμένος φαιδρολογώντας φακκώντας φαλιρισμένος
 φαρμακωμένος φεγγοβολώντας φελώντας φερμένος φερόμενος φημισμένος φθίνουσα
 φθαρμένος φθειριώντας φθινοπωριάτικα φθισιώντας φιλοδοξώντας φιλοκαλώντας
 φιλοσοφώντας φιλοτεχνώντας φιλοφρονώντας φιξαρισμένος φιστικώνοντας φλεγμαίνων
 φληναφώντας φλιπαρισμένος φλογισμένος φλογοβολώντας φοβισμένος φοδραρισμένος
 φορμαρισμένος φορολογούμενος φορτισμένος φορτσαρισμένος φορτωμένος φουντωμένος
 φουρτουνιασμένος φουσκωμένος φραγκοκρατούμενος φραγμένος φρακαρισμένος
 φροκαλώντας φρονηματισμένος φροντισμένος φρουρημένος φρουρούμενος φταίγοντας
 φτιαγμένος φτουρώντας φυγοκεντρισμένος φυλαγμένος φυλακισμένος φυλασσόμενος
 φυτεμένος φυτευμένος φυτοζοώντας φυτρωμένος φωσφατωμένος φωσφορυλιωμένος
 φωταγωγώντας φωτισμένος φωτοβολώντας φωτογραφώντας φωτοευαισθητοποιημένος
 χαζολογώντας χαιράμενος χαιρεκακώντας χαιρόμενος χαλαρωμένος χαλασμένος
 χαλκευμένος χαλκογραφώντας χαλνώντας χαλυβοποιώντας χαμένος χαμηλωμένος
 χαρακωμένος χαριτολογώντας χαριτωμένος χαροκαμένος χαροκοπώντας χαροποιώντας
 χαρτογραφημένος χαρτογραφώντας χαρτοδετώντας χασκογελώντας χαϊδεμένος
 χειμαζόμενος χειραγωγημένος χειραγωγώντας χειραφετημένος χειροπεδώντας
 χειρουργημένος χειρουργώντας χερομαχώντας χεσμένος χιλιοπαιγμένος χιμώντας
 χιονοβολώντας χλαπακιάζοντας χλιμιντρώντας χλωριωμένος χολεριασμένος
 χολιασμένος χολοσκώντας χολωμένος χοντροκαμωμένος χορεύοντας χορηγηθείς
 χορηγημένο χορηγημένος χορηγώντας χοροστατώντας χορταριασμένος χορτασμένος
 χοχλακώντας χρειαζούμενος χρεοκοπώντας χρεωκοπημένος χρεωκοπώντας χρεωμένος
 χρηματισάντων χρηματολογώντας χρησιμοποιημένος χρησιμοποιούμενος
 χρησμοδοτώντας χρησμολογώντας χρισμένος χρονογραφώντας χρονολογημένος
 χρυσοκεντώντας χρυσωμένος χρωστούμενος χτενισμένος χτισμένος χτυπημένος
 χυλοποιώντας χυλωμένος χυμένος χωμένος χωνεμένος χωρισμένος χωροθετημένος
 χωροσταθμώντας χωρώντας ψάλλοντας ψαγμένος ψαρωμένος ψειριασμένος ψεκασμένος
 ψευτοζώντας ψευτοπερνώντας ψηλαφημένος ψηλαφισμένος ψημένος ψηφισμένος
 ψηφοθηρώντας ψηφοφορώντας ψηφώντας ψιλοδουλεμένος ψιλολογώντας ψιλομεθυσμένος
 ψιλούμενος ψοφολογώντας ψυχογραφώντας ψυχολογημένος ψυχομαχώντας ψυχομαχώντας
 ψυχορραγώντας ψυχρηλατώντας ψυχωμένος ψωμοζητώντας ψωμοζώντας ψωμωμένος
 ωθηθείς ωθώντας ωραιοποιημένος ωραιοποιώντας ωρυόμενος ωτοσκοπώντας όντας
""".split())



# coding: utf8
from __future__ import unicode_literals

import pytest


NB_TOKEN_EXCEPTION_TESTS = [
    ('Smørsausen brukes bl.a. til fisk', ['Smørsausen', 'brukes', 'bl.a.', 'til', 'fisk']),
    ('Jeg kommer først kl. 13 pga. diverse forsinkelser', ['Jeg', 'kommer', 'først', 'kl.', '13', 'pga.', 'diverse', 'forsinkelser'])
]


@pytest.mark.parametrize('text,expected_tokens', NB_TOKEN_EXCEPTION_TESTS)
def test_tokenizer_handles_exception_cases(nb_tokenizer, text, expected_tokens):
    tokens = nb_tokenizer(text)
    token_list = [token.text for token in tokens if not token.is_space]
    assert expected_tokens == token_list



# coding: utf-8
from __future__ import unicode_literals

import pytest


def test_en_tokenizer_handles_basic_contraction(en_tokenizer):
    text = "don't giggle"
    tokens = en_tokenizer(text)
    assert len(tokens) == 3
    assert tokens[1].text == "n't"
    text = "i said don't!"
    tokens = en_tokenizer(text)
    assert len(tokens) == 5
    assert tokens[4].text == "!"


@pytest.mark.parametrize('text', ["`ain't", '''"isn't''', "can't!"])
def test_en_tokenizer_handles_basic_contraction_punct(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 3


@pytest.mark.parametrize('text_poss,text', [("Robin's", "Robin"), ("Alexis's", "Alexis")])
def test_en_tokenizer_handles_poss_contraction(en_tokenizer, text_poss, text):
    tokens = en_tokenizer(text_poss)
    assert len(tokens) == 2
    assert tokens[0].text == text
    assert tokens[1].text == "'s"


@pytest.mark.parametrize('text', ["schools'", "Alexis'"])
def test_en_tokenizer_splits_trailing_apos(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 2
    assert tokens[0].text == text.split("'")[0]
    assert tokens[1].text == "'"


@pytest.mark.parametrize('text', ["'em", "nothin'", "ol'"])
def text_tokenizer_doesnt_split_apos_exc(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 1
    assert tokens[0].text == text


@pytest.mark.parametrize('text', ["we'll", "You'll", "there'll"])
def test_en_tokenizer_handles_ll_contraction(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 2
    assert tokens[0].text == text.split("'")[0]
    assert tokens[1].text == "'ll"
    assert tokens[1].lemma_ == "will"


@pytest.mark.parametrize('text_lower,text_title', [("can't", "Can't"), ("ain't", "Ain't")])
def test_en_tokenizer_handles_capitalization(en_tokenizer, text_lower, text_title):
    tokens_lower = en_tokenizer(text_lower)
    tokens_title = en_tokenizer(text_title)
    assert tokens_title[0].text == tokens_lower[0].text.title()
    assert tokens_lower[0].text == tokens_title[0].text.lower()
    assert tokens_lower[1].text == tokens_title[1].text


@pytest.mark.parametrize('pron', ["I", "You", "He", "She", "It", "We", "They"])
@pytest.mark.parametrize('contraction', ["'ll", "'d"])
def test_en_tokenizer_keeps_title_case(en_tokenizer, pron, contraction):
    tokens = en_tokenizer(pron + contraction)
    assert tokens[0].text == pron
    assert tokens[1].text == contraction


@pytest.mark.parametrize('exc', ["Ill", "ill", "Hell", "hell", "Well", "well"])
def test_en_tokenizer_excludes_ambiguous(en_tokenizer, exc):
    tokens = en_tokenizer(exc)
    assert len(tokens) == 1


@pytest.mark.parametrize('wo_punct,w_punct', [("We've", "``We've"), ("couldn't", "couldn't)")])
def test_en_tokenizer_splits_defined_punct(en_tokenizer, wo_punct, w_punct):
    tokens = en_tokenizer(wo_punct)
    assert len(tokens) == 2
    tokens = en_tokenizer(w_punct)
    assert len(tokens) == 3


@pytest.mark.parametrize('text', ["e.g.", "p.m.", "Jan.", "Dec.", "Inc."])
def test_en_tokenizer_handles_abbr(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 1


def test_en_tokenizer_handles_exc_in_text(en_tokenizer):
    text = "It's mediocre i.e. bad."
    tokens = en_tokenizer(text)
    assert len(tokens) == 6
    assert tokens[3].text == "i.e."


@pytest.mark.parametrize('text', ["1am", "12a.m.", "11p.m.", "4pm"])
def test_en_tokenizer_handles_times(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert len(tokens) == 2
    assert tokens[1].lemma_ in ["a.m.", "p.m."]


@pytest.mark.parametrize('text,norms', [("I'm", ["i", "am"]), ("shan't", ["shall", "not"])])
def test_en_tokenizer_norm_exceptions(en_tokenizer, text, norms):
    tokens = en_tokenizer(text)
    assert [token.norm_ for token in tokens] == norms


@pytest.mark.parametrize('text,norm', [("radicalised", "radicalized"), ("cuz", "because")])
def test_en_lex_attrs_norm_exceptions(en_tokenizer, text, norm):
    tokens = en_tokenizer(text)
    assert tokens[0].norm_ == norm
